-------------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
-------------------------------------------------------------------------------
--    File Information: %W%
--    Revision: %I%
--    Date: %G% %U%
-------------------------------------------------------------------------------


-------------------------------------
---  APP HELPER TEMPORARY TABLES
------------------------------------

-- HELPER TABLES FOR LISTING J2EE_SERVER AND J2EE_SERVER GROUP(NO RELATIONSHIP LINKS)
declare global temporary table JDOMAIN_TO_SERVER (
    DOMAIN_ID INTEGER,
    DOMAIN_NM VARCHAR(254),
    SERVER_ID INTEGER
    )
with replace on commit preserve rows not logged;

INSERT INTO SESSION.JDOMAIN_TO_SERVER
 SELECT
  C_DOMAIN.COMP_ID AS DOMAIN_ID,
  C_DOMAIN.COMP_NM AS DOMAIN_NM,
  C_SERVER.COMP_ID AS SERVER_ID
 FROM
  TWG.CUR_COMP C_DOMAIN,
  TWG.CUR_COMP C_SERVER,
  TWG.CUR_COMPRELN R
 WHERE
  C_DOMAIN.COMPTYP_CD IN ('J2EE_DOMAIN') AND
  C_SERVER.COMPTYP_CD IN ('J2EE_SERVER') AND
  R.COMP_SOURCE_ID=C_DOMAIN.COMP_ID AND R.COMP_TARGET_ID=C_SERVER.COMP_ID AND
  R.RELNTYP_CD='PCHILD'
 GROUP BY
  C_DOMAIN.COMP_ID, C_DOMAIN.COMP_NM, C_SERVER.COMP_ID
;

declare global temporary table JNODE_TO_SERVER (
    NODE_ID INTEGER,
    NODE_NM VARCHAR(254),
    SERVER_ID INTEGER
    )
with replace on commit preserve rows not logged;

--JMG, 127088, Use CUR_COMPRELN
INSERT INTO SESSION.JNODE_TO_SERVER
 SELECT
  C_NODE.COMP_ID AS NODE_ID,
  C_NODE.COMP_NM AS NODE_NM,
  C_SERVER.COMP_ID AS SERVER_ID
 FROM
  TWG.CUR_COMP C_NODE,
  TWG.CUR_COMP C_SERVER,
  TWG.CUR_COMPRELN R
 WHERE
  C_NODE.COMPTYP_CD IN ('J2EE_NODE') AND
  C_SERVER.COMPTYP_CD IN ('J2EE_SERVER') AND
  R.COMP_SOURCE_ID=C_NODE.COMP_ID AND R.COMP_TARGET_ID=C_SERVER.COMP_ID AND
  R.RELNTYP_CD='PCHILD'
 GROUP BY
  C_NODE.COMP_ID, C_NODE.COMP_NM, C_SERVER.COMP_ID
;

declare global temporary table JCELL_TO_SERVER (
    CELL_ID INTEGER,
    CELL_NM VARCHAR(254),
    NODE_ID INTEGER,
    SERVER_ID INTEGER
    )
with replace on commit preserve rows not logged;

--JMG, 127088, Use CUR_COMPRELN
INSERT INTO SESSION.JCELL_TO_SERVER
 SELECT
  C_CELL.COMP_ID AS CELL_ID,
  C_CELL.COMP_NM AS CELL_NM,
  JNODE.NODE_ID AS NODE_ID,
  JNODE.SERVER_ID AS SERVER_ID
 FROM
  TWG.CUR_COMP C_CELL,
  SESSION.JNODE_TO_SERVER JNODE,
  TWG.CUR_COMPRELN R
 WHERE
  C_CELL.COMPTYP_CD IN ('J2EE_CELL') AND
  R.COMP_SOURCE_ID=C_CELL.COMP_ID AND R.COMP_TARGET_ID=JNODE.NODE_ID AND
  R.RELNTYP_CD='PCHILD'
 GROUP BY
  C_CELL.COMP_ID, C_CELL.COMP_NM, JNODE.NODE_ID, JNODE.SERVER_ID
;

--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
DROP TABLE BWM.STG_D_APP;

-- STAGE D_APP
CREATE TABLE BWM.STG_D_APP(
    ORIG_APP_ID INTEGER NOT NULL,
    J2EESERVER_NAME VARCHAR(254),
    J2EE_CELL_NAME VARCHAR(254),
    J2EE_DOMAIN VARCHAR(254),
    J2EE_NODE VARCHAR(254),
    J2EE_TYPE_VER VARCHAR(254),
    PROBE_HOST VARCHAR(254),
    PROBE_NAME VARCHAR(254),
    PRIMARY KEY (ORIG_APP_ID)
    );

INSERT INTO BWM.STG_D_APP
 SELECT
  C_PROBE.COMP_ID AS ORIG_APP_ID,
  'N/A' AS J2EESERVER_NAME,
  'N/A' AS J2EE_CELL_NAME,
  'N/A' AS J2EE_DOMAIN,
  'N/A' AS J2EE_NODE,
  'N/A' AS J2EE_TYPE_VER,
  C_PROBE_HOST.COMP_NM AS PROBE_HOST,
  C_PROBE.COMP_NM AS PROBE_NAME
 FROM
  TWG.CUR_COMP C_PROBE,
  TWG.CUR_COMP C_PROBE_HOST,
  TWG.CUR_COMPRELN R
 WHERE
  C_PROBE.COMPTYP_CD IN ('BWM_PROBE') AND
  C_PROBE_HOST.COMPTYP_CD IN ('IP_HOST','IP_INTERFACE','BWM_HOST') AND
  R.COMP_SOURCE_ID=C_PROBE.COMP_ID AND R.COMP_TARGET_ID=C_PROBE_HOST.COMP_ID AND
  R.RELNTYP_CD='RUNSON'
  ;

INSERT INTO BWM.STG_D_APP
 SELECT
  C_J2EESERVER.COMP_ID AS ORIG_APP_ID,
  C_J2EESERVER.COMP_NM AS J2EESERVER_NAME,
  VALUE(MIN(JC.CELL_NM),'N/A') AS J2EE_CELL_NAME,
  VALUE(MIN(JD.DOMAIN_NM),'N/A') AS J2EE_DOMAIN_NAME,
  VALUE(MIN(JN.NODE_NM),'N/A') AS J2EE_NODE,
  CONCAT(VALUE(MIN(A1.COMPATTR_VAL),'N/A'),VALUE(MIN(A2.COMPATTR_VAL),' ')) AS J2EE_TYPE_VER,
  'N/A' AS PROBE_HOST,
  'N/A' AS PROBE_NAME
 FROM
  TWG.CUR_COMP C_J2EESERVER LEFT OUTER JOIN SESSION.JCELL_TO_SERVER JC
   ON C_J2EESERVER.COMP_ID=JC.SERVER_ID,
  TWG.CUR_COMP C_SERVER1 LEFT OUTER JOIN SESSION.JDOMAIN_TO_SERVER JD
   ON C_SERVER1.COMP_ID=JD.SERVER_ID,
  TWG.CUR_COMP C_SERVER2 LEFT OUTER JOIN SESSION.JNODE_TO_SERVER JN
   ON C_SERVER2.COMP_ID=JN.SERVER_ID,
  TWG.CUR_COMP C_SERVER3 LEFT OUTER JOIN TWG.CUR_COMPATTR A1
   ON C_SERVER3.COMP_ID=A1.COMP_ID AND A1.ATTRTYP_CD='MANUFACTURER',
  TWG.CUR_COMP C_SERVER4 LEFT OUTER JOIN TWG.CUR_COMPATTR A2
   ON C_SERVER4.COMP_ID=A2.COMP_ID AND A2.ATTRTYP_CD='VERSION'
 WHERE
  C_J2EESERVER.COMPTYP_CD IN ('J2EE_SERVER') AND
  C_J2EESERVER.COMP_ID=C_SERVER1.COMP_ID AND
  C_J2EESERVER.COMP_ID=C_SERVER2.COMP_ID AND
  C_J2EESERVER.COMP_ID=C_SERVER3.COMP_ID AND
  C_J2EESERVER.COMP_ID=C_SERVER4.COMP_ID
 GROUP BY
  C_J2EESERVER.COMP_ID,C_J2EESERVER.COMP_NM
;

----------------------
-- BWM_TX_NODE
-----------------------
--#EXECUTE_AT_TARGET
--#IGNORE_ERROR
DROP TABLE BWM.STG_D_TX_ND;

--JMG, 127088, Added primary key and not null
CREATE TABLE BWM.STG_D_TX_ND(
    ORIG_TX_ND_ID INTEGER NOT NULL,
    TX_ND_NAME VARCHAR(254),
    MANAGEMENT_POLICY VARCHAR(254),
    INVOKING_USER VARCHAR(254),
    ROOT_CDW_ID         VARCHAR(254),
    PARENT_CDW_ID       VARCHAR(254),
    PRIMARY KEY (ORIG_TX_ND_ID)
    );


--- STG_D_TX_ND
INSERT INTO BWM.STG_D_TX_ND
 SELECT
  C_TX_ND2.COMP_ID AS ORIG_TX_ND_ID,
  C_TX_ND2.COMP_NM AS TX_ND_NAME,
  VALUE(MIN(A_MANAGEMENT_POLICY.COMPATTR_VAL),'N/A') AS MANAGEMENT_POLICY,
  VALUE(MIN(A_INVOKING_USER.COMPATTR_VAL),'N/A') AS INVOKING_USER,
  VALUE(MIN(A_ROOT_ID.COMPATTR_VAL),'N/A') AS ROOT_CDW_ID,
  VALUE(MIN(A_PARENT_ID.COMPATTR_VAL),'N/A') AS PARENT_CDW_ID
 FROM
  TWG.CUR_COMP C_TX_ND2 LEFT OUTER JOIN TWG.CUR_COMPATTR A_MANAGEMENT_POLICY
   ON C_TX_ND2.COMP_ID=A_MANAGEMENT_POLICY.COMP_ID AND A_MANAGEMENT_POLICY.ATTRTYP_CD='BWM_MGMT_POLICY',
  TWG.CUR_COMP C_TX_ND3 LEFT OUTER JOIN TWG.CUR_COMPATTR A_INVOKING_USER
   ON C_TX_ND3.COMP_ID=A_INVOKING_USER.COMP_ID AND A_INVOKING_USER.ATTRTYP_CD='INVOKING_USER',
  TWG.CUR_COMP C_TX_ND4 LEFT OUTER JOIN TWG.CUR_COMPATTR A_ROOT_ID
   ON C_TX_ND4.COMP_ID=A_ROOT_ID.COMP_ID AND A_ROOT_ID.ATTRTYP_CD='BWM_RT_CDW_ID',
  TWG.CUR_COMP C_TX_ND5 LEFT OUTER JOIN TWG.CUR_COMPATTR A_PARENT_ID
   ON C_TX_ND5.COMP_ID=A_PARENT_ID.COMP_ID AND A_PARENT_ID.ATTRTYP_CD='BWM_PT_CDW_ID',
  BWM.STG_D_APP C_APP,
  TWG.CUR_COMP C_TX,
  TWG.CUR_COMPRELN R,
  TWG.CUR_COMPRELN R2
 WHERE
  C_TX_ND2.COMPTYP_CD='BWM_TX_NODE' AND
  C_TX_ND2.COMP_ID=C_TX_ND3.COMP_ID AND
  R.COMP_SOURCE_ID=C_TX_ND2.COMP_ID AND
  R.COMP_TARGET_ID=C_TX.COMP_ID AND
  R.RELNTYP_CD='INSTOF' AND
  C_TX.COMPTYP_CD='BWM_TRANSACTION' AND
  C_APP.PROBE_NAME='N/A' AND
  R2.RELNTYP_CD='USES' AND
  R2.COMP_SOURCE_ID=C_TX_ND2.COMP_ID AND
  R2.COMP_TARGET_ID=C_APP.ORIG_APP_ID AND
  C_TX_ND2.COMP_ID=C_TX_ND4.COMP_ID AND
  C_TX_ND2.COMP_ID=C_TX_ND5.COMP_ID
GROUP BY
  C_TX_ND2.COMP_ID,C_TX_ND2.COMP_NM
;

--- STG_D_TX_ND
INSERT INTO BWM.STG_D_TX_ND
SELECT
  C_TX_ND2.COMP_ID AS ORIG_TX_ND_ID,
  C_TX_ND2.COMP_NM AS TX_ND_NAME,
  VALUE(MIN(A_MANAGEMENT_POLICY.COMPATTR_VAL),'N/A') AS MANAGEMENT_POLICY,
  VALUE(MIN(A_INVOKING_USER.COMPATTR_VAL),'N/A') AS INVOKING_USER,
  VALUE(MIN(A_ROOT_ID.COMPATTR_VAL),'N/A') AS ROOT_CDW_ID,
  VALUE(MIN(A_PARENT_ID.COMPATTR_VAL),'N/A') AS PARENT_CDW_ID
 FROM
  TWG.CUR_COMP C_TX_ND2 LEFT OUTER JOIN TWG.CUR_COMPATTR A_MANAGEMENT_POLICY
   ON C_TX_ND2.COMP_ID=A_MANAGEMENT_POLICY.COMP_ID AND A_MANAGEMENT_POLICY.ATTRTYP_CD='BWM_MGMT_POLICY',
  TWG.CUR_COMP C_TX_ND3 LEFT OUTER JOIN TWG.CUR_COMPATTR A_INVOKING_USER
   ON C_TX_ND3.COMP_ID=A_INVOKING_USER.COMP_ID AND A_INVOKING_USER.ATTRTYP_CD='INVOKING_USER',
  TWG.CUR_COMP C_TX_ND4 LEFT OUTER JOIN TWG.CUR_COMPATTR A_ROOT_ID
   ON C_TX_ND4.COMP_ID=A_ROOT_ID.COMP_ID AND A_ROOT_ID.ATTRTYP_CD='BWM_RT_CDW_ID',
  TWG.CUR_COMP C_TX_ND5 LEFT OUTER JOIN TWG.CUR_COMPATTR A_PARENT_ID
   ON C_TX_ND5.COMP_ID=A_PARENT_ID.COMP_ID AND A_PARENT_ID.ATTRTYP_CD='BWM_PT_CDW_ID',
  BWM.STG_D_APP C_APP,
  TWG.CUR_COMP C_TX,
  TWG.CUR_COMPRELN R,
  TWG.CUR_COMPRELN R2
WHERE
  C_TX_ND2.COMPTYP_CD='BWM_TX_NODE' AND
  C_TX_ND2.COMP_ID=C_TX_ND3.COMP_ID AND
  R.COMP_SOURCE_ID=C_TX_ND2.COMP_ID AND R.COMP_TARGET_ID=C_TX.COMP_ID AND
  R.RELNTYP_CD='INSTOF' AND C_TX.COMPTYP_CD='BWM_TRANSACTION' AND
  C_APP.J2EESERVER_NAME='N/A' AND R2.RELNTYP_CD='INVOKE' AND
  R2.COMP_SOURCE_ID=C_APP.ORIG_APP_ID AND R2.COMP_TARGET_ID=C_TX_ND2.COMP_ID AND
  C_TX_ND2.COMP_ID=C_TX_ND4.COMP_ID AND
  C_TX_ND2.COMP_ID=C_TX_ND5.COMP_ID
GROUP BY
  C_TX_ND2.COMP_ID,C_TX_ND2.COMP_NM
;

-----------------
-- STG_F_TX_ND_HR
-----------------


--REVISION 20040722
--USE REAL TABLES TO ALLOW PRIMARY KEYS

--declare global temporary table TX_TO_TX_ND (
--    TX_ND_ID INTEGER,
--    TX_ID INTEGER
--    )
--with replace on commit preserve rows not logged;

--#IGNORE_ERROR
DROP TABLE BWM.TMP_TX_TO_TX_ND;

CREATE TABLE BWM.TMP_TX_TO_TX_ND (
    TX_ND_ID INTEGER NOT NULL,
    TX_ID INTEGER
--,PRIMARY KEY(TX_ND_ID)
)
;

insert into BWM.TMP_TX_TO_TX_ND
select
 C1.COMP_ID AS TX_ND_ID,
 C2.COMP_ID AS TX_ID
from
 TWG.CUR_COMP C2,
 TWG.CUR_COMPRELN R1,
 TWG.CUR_COMP C1
WHERE
 R1.COMP_SOURCE_ID=C1.COMP_ID AND
 R1.COMP_TARGET_ID=C2.COMP_ID AND
 R1.RELNTYP_CD='INSTOF' AND
 C1.COMPTYP_CD='BWM_TX_NODE'
group by
 C1.COMP_ID, C2.COMP_ID
;

--REVISION 20040722
--USE REAL TABLES TO ALLOW PRIMARY KEYS

--declare global temporary table HOST_TO_TX_ND (
--    TX_ND_ID INTEGER,
--    HOST_ID INTEGER
--    )
--with replace on commit preserve rows not logged;

--#IGNORE_ERROR
DROP TABLE BWM.TMP_HOST_TO_TX_ND;

CREATE TABLE BWM.TMP_HOST_TO_TX_ND (
    TX_ND_ID INTEGER NOT NULL,
    HOST_ID INTEGER,
    PRIMARY KEY(TX_ND_ID)
    )
;

insert into BWM.TMP_HOST_TO_TX_ND
select
 C1.COMP_ID AS TX_ND_ID,
 C2.COMP_ID AS HOST_ID
from
 TWG.CUR_COMP C2,
 TWG.CUR_COMPRELN R1,
 TWG.CUR_COMP C1
WHERE
 R1.COMP_SOURCE_ID=C1.COMP_ID AND R1.COMP_TARGET_ID=C2.COMP_ID AND
 R1.RELNTYP_CD='RUNSON' AND
 C2.COMPTYP_CD in ('IP_HOST', 'BWM_HOST') AND
 C1.COMPTYP_CD='BWM_TX_NODE'
group by
 C1.COMP_ID, C2.COMP_ID
;

--REVISION 20040722
--USE REAL TABLES TO ALLOW PRIMARY KEYS

--declare global temporary table J2EE_TO_TX_ND (
--    TX_ND_ID INTEGER,
--    J2EE_ID INTEGER
--    )
--with replace on commit preserve rows not logged;

--#IGNORE_ERROR
DROP TABLE BWM.TMP_J2EE_TO_TX_ND;

CREATE TABLE BWM.TMP_J2EE_TO_TX_ND (
    TX_ND_ID INTEGER NOT NULL,
    J2EE_ID INTEGER,
    PRIMARY KEY(TX_ND_ID)
    )
;

insert into BWM.TMP_J2EE_TO_TX_ND
select
 C1.COMP_ID AS TX_ND_ID,
 C2.COMP_ID AS J2EE_ID
from
 TWG.CUR_COMP C2,
 TWG.CUR_COMPRELN R1,
 TWG.CUR_COMP C1
WHERE
 R1.COMP_SOURCE_ID=C1.COMP_ID AND R1.COMP_TARGET_ID=C2.COMP_ID AND
 R1.RELNTYP_CD='USES' AND
 C2.COMPTYP_CD='J2EE_SERVER' AND
 C1.COMPTYP_CD='BWM_TX_NODE'
group by
 C1.COMP_ID, C2.COMP_ID
;

--REVISION 20040722
--USE REAL TABLES TO ALLOW PRIMARY KEYS

--declare global temporary table PROBE_TO_TX_ND (
--    TX_ND_ID INTEGER,
--    PROBE_ID INTEGER
--    )
--with replace on commit preserve rows not logged;

--#IGNORE_ERROR
DROP TABLE BWM.TMP_PROBE_TO_TX_ND;

CREATE TABLE  BWM.TMP_PROBE_TO_TX_ND (
    TX_ND_ID INTEGER NOT NULL,
    PROBE_ID INTEGER,
    PRIMARY KEY(TX_ND_ID)
  )
;

insert into BWM.TMP_PROBE_TO_TX_ND
select
 C1.COMP_ID AS TX_ND_ID,
 C2.COMP_ID AS PROBE_ID
from
 TWG.CUR_COMP C2,
 TWG.CUR_COMPRELN R1,
 TWG.CUR_COMP C1
WHERE
 R1.COMP_SOURCE_ID=C2.COMP_ID AND R1.COMP_TARGET_ID=C1.COMP_ID AND
 R1.RELNTYP_CD='INVOKE' AND
 C2.COMPTYP_CD='BWM_PROBE' AND
 C1.COMPTYP_CD='BWM_TX_NODE'
group by
 C1.COMP_ID, C2.COMP_ID
;

--#IGNORE_ERROR
DROP TABLE BWM.STG_CDW_TX_ND_HR;

CREATE TABLE BWM.STG_CDW_TX_ND_HR(
    CDW_ID INTEGER NOT NULL,
    MSMT_ID INTEGER NOT NULL,
    ORIG_TX_ND_ID INTEGER NOT NULL,
    ORIG_TX_ID INTEGER NOT NULL,
    ORIG_APP_ID INTEGER NOT NULL,
    ORIG_HOST_ID INTEGER NOT NULL,
    ORIG_METRIC_ID INTEGER NOT NULL,
    MEAS_HOUR TIMESTAMP NOT NULL,
    MIN_VALUE FLOAT,
    MAX_VALUE FLOAT,
    AVG_VALUE FLOAT,
    TOTAL_VALUE FLOAT,
    SAMPLE_COUNT INTEGER,
    ERROR_COUNT INTEGER,
    PRIMARY KEY (ORIG_TX_ND_ID,ORIG_TX_ID,ORIG_APP_ID,
     ORIG_HOST_ID,ORIG_METRIC_ID,CDW_ID,MEAS_HOUR)
    )
    ;

--REVISION 20040722
--USE TEMPORARY TABLE TO MINIMISE EXECUTION TIME ON THE INSERT QUERY SELECTING
--FROM THE TWG.MSMT and TWG.MSMTTYP TABLES.
--TRY ORDER BY MSMT_ID ON INSERT TO SEE IF THIS IS BETTER THAN ORDER BY COMP_ID
--Also
--Select all BWM rows from TWG.MSMT using 'BWM' MSRC_CORR_ID only (currently we only insert BWM_TX_NODE comps and msmts)
--Do TIMESTAMP operation on SELECT for MEAS_HOUR instead of on the PROBE and J2EE INSERT to avoid any duplication of effort

--#IGNORE_ERROR
DROP TABLE BWM.TMP_MSMT;

--CREATE TABLE BWM.TMP_MSMT(
DECLARE GLOBAL TEMPORARY TABLE TMP_MSMT(
    MSMT_ID BIGINT NOT NULL,
    COMP_ID INTEGER NOT NULL,
    MSMTTYP_ID INTEGER,
    TMSUM_CD CHAR(1),
    MEAS_HOUR TIMESTAMP,
    MSMT_MIN_VAL DOUBLE,
    MSMT_MAX_VAL DOUBLE,
    MSMT_AVG_VAL DOUBLE,
    MSMT_TOT_VAL DOUBLE,
    MSMT_SMPL_CNT INTEGER,
    MSMT_ERR_CNT INTEGER,
    MSMTTYP_NM INTEGER)
with replace on commit preserve rows not logged
;

INSERT INTO SESSION.TMP_MSMT
	SELECT
		M1.MSMT_ID ,
		M1.COMP_ID ,
    		M1.MSMTTYP_ID ,
    		M1.TMSUM_CD ,
          TIMESTAMP(M1.MSMT_STRT_DT,M1.MSMT_STRT_TM) AS MEAS_HOUR,
    		M1.MSMT_MIN_VAL ,
    		M1.MSMT_MAX_VAL ,
    		M1.MSMT_AVG_VAL ,
    		M1.MSMT_TOT_VAL ,
    		M1.MSMT_SMPL_CNT ,
    		M1.MSMT_ERR_CNT,
    		0 AS MSMTTYP
	FROM
		TWG.MSMT M1
--	WHERE
--    MSrc_Corr_Cd='BWM'
  ORDER BY COMP_ID
;

--REVISION 20040722
--Update the 'Response Time'(MIN, MAX, AVG: /1000) on the TMP_MSMT table rather than the SELECT from TWG.MSMT (avoids CASE)
UPDATE SESSION.TMP_MSMT M
SET MSMT_MIN_VAL = MSMT_MIN_VAL/1000, MSMT_AVG_VAL = MSMT_AVG_VAL/1000, MSMT_TOT_VAL = MSMT_TOT_VAL/1000
WHERE M.MSMTTYP_ID = (
   SELECT MT.MSMTTYP_ID
   FROM TWG.MSMTTYP MT, TWG.MSMTRUL MR
   WHERE
      MT.MSMTTYP_ID = MR.MSMTTYP_ID
      AND MR.COMPTYP_CD = 'BWM_TX_NODE'
      AND MT.MSRC_CD = 'MODEL1'
      AND MT.MSMTTYP_NM IN ('Response Time'))
;

--REVISION 20040622
--INSERT STATEMENT REPLACED.  FEWER JOINS. SINGLE JOIN ON TEMP TABLE.  OTHERS INDEXED.

--INSERT INTO BWM.STG_CDW_TX_ND_HR  (CDW_ID,  MSMT_ID, ORIG_TX_ND_ID, ORIG_TX_ID, ORIG_APP_ID, ORIG_HOST_ID, ORIG_METRIC_ID, MEAS_HOUR, MIN_VALUE, MAX_VALUE, AVG_VALUE, TOTAL_VALUE,  SAMPLE_COUNT,  ERROR_COUNT )
-- SELECT
--  1 AS CDW_ID,
--  M1.MSMT_ID,
--  M1.COMP_ID AS ORIG_TX_ND_ID,
--  TX.TX_ID AS ORIG_TX_ID,
--  P.PROBE_ID AS ORIG_APP_ID,
--  H.HOST_ID AS ORIG_HOST_ID,
--  M1.MSMTTYP_ID AS ORIG_METRIC_ID,
--  TIMESTAMP(M1.MSMT_STRT_DT,M1.MSMT_STRT_TM) AS MEAS_HOUR,
--  CASE WHEN MT.MSMTTYP_NM='Response Time' then MIN(M1.MSMT_MIN_VAL/1000) ELSE MIN(M1.MSMT_MIN_VAL) END AS MIN_VALUE,
--  CASE WHEN MT.MSMTTYP_NM='Response Time' then MAX(M1.MSMT_MAX_VAL/1000) ELSE MAX(M1.MSMT_MAX_VAL) END AS MAX_VALUE,
--  CASE WHEN MT.MSMTTYP_NM='Response Time' then AVG(M1.MSMT_AVG_VAL/1000) ELSE AVG(M1.MSMT_AVG_VAL) END AS AVG_VALUE,
--  SUM(M1.MSMT_TOT_VAL) AS TOTAL_VALUE,
--  MAX(M1.MSMT_SMPL_CNT) AS SAMPLE_COUNT,
--  MAX(M1.MSMT_ERR_CNT) AS ERROR_COUNT
-- FROM
--  TWG.MSMT M1 ,
--  TWG.MSMTTYP MT,
--  TWG.CUR_COMP C1,
--  SESSION.PROBE_TO_TX_ND P,
--  SESSION.TX_TO_TX_ND TX,
--  SESSION.HOST_TO_TX_ND H
-- WHERE
--  M1.COMP_ID=C1.COMP_ID AND
--  C1.COMPTYP_CD = 'BWM_TX_NODE' AND
--  M1.TMSUM_CD='H' AND
--  M1.MSMTTYP_ID=MT.MSMTTYP_ID AND
--  P.TX_ND_ID=TX.TX_ND_ID AND
--  P.TX_ND_ID=H.TX_ND_ID AND
--  P.TX_ND_ID=M1.COMP_ID
-- GROUP BY
--  M1.MSMT_ID,M1.COMP_ID,M1.MSMTTYP_ID,M1.MSMT_STRT_DT,M1.MSMT_STRT_TM,TX.TX_ID,P.PROBE_ID,H.HOST_ID,MT.MSMTTYP_NM
--;

--20040622 REVISED
INSERT INTO BWM.STG_CDW_TX_ND_HR  (CDW_ID,  MSMT_ID, ORIG_TX_ND_ID, ORIG_TX_ID, ORIG_APP_ID, ORIG_HOST_ID, ORIG_METRIC_ID, MEAS_HOUR, MIN_VALUE, MAX_VALUE, AVG_VALUE, TOTAL_VALUE,  SAMPLE_COUNT,  ERROR_COUNT )
 SELECT
  1 AS CDW_ID,
  M1.MSMT_ID,
  M1.COMP_ID AS ORIG_TX_ND_ID,
  TX.TX_ID AS ORIG_TX_ID,
  P.PROBE_ID AS ORIG_APP_ID,
  H.HOST_ID AS ORIG_HOST_ID,
  M1.MSMTTYP_ID AS ORIG_METRIC_ID,
  M1.MEAS_HOUR,
  MIN(M1.MSMT_MIN_VAL) AS MIN_VALUE,
  MAX(M1.MSMT_MAX_VAL)AS MAX_VALUE,
  AVG(M1.MSMT_AVG_VAL) AS AVG_VALUE,
  SUM(M1.MSMT_TOT_VAL) AS TOTAL_VALUE,
  MAX(M1.MSMT_SMPL_CNT) AS SAMPLE_COUNT,
  MAX(M1.MSMT_ERR_CNT) AS ERROR_COUNT
 FROM
  SESSION.TMP_MSMT M1 ,
  BWM.TMP_PROBE_TO_TX_ND P,
  BWM.TMP_TX_TO_TX_ND TX,
  BWM.TMP_HOST_TO_TX_ND H
 WHERE
  P.TX_ND_ID=TX.TX_ND_ID AND
  P.TX_ND_ID=H.TX_ND_ID AND
  P.TX_ND_ID=M1.COMP_ID
 GROUP BY
  M1.MSMT_ID,M1.COMP_ID,M1.MSMTTYP_ID,M1.MEAS_HOUR,TX.TX_ID,P.PROBE_ID,H.HOST_ID,M1.MSMTTYP_NM
;

--REVISION 20040622
--INSERT STATEMENT REPLACED.  FEWER JOINS. SINGLE JOIN ON TEMP TABLE.  OTHERS INDEXED.

--INSERT INTO BWM.STG_CDW_TX_ND_HR (CDW_ID,  MSMT_ID, ORIG_TX_ND_ID, ORIG_TX_ID, ORIG_APP_ID, ORIG_HOST_ID, ORIG_METRIC_ID, MEAS_HOUR, MIN_VALUE, MAX_VALUE, AVG_VALUE, TOTAL_VALUE,  SAMPLE_COUNT,  ERROR_COUNT )
-- SELECT
--  1 AS CDW_ID,
--  M2.MSMT_ID,
--  M2.COMP_ID AS ORIG_TX_ND_ID,
--  TX.TX_ID AS ORIG_TX_ID,
--  J.J2EE_ID AS ORIG_APP_ID,
--  H.HOST_ID AS ORIG_HOST_ID,
--  M2.MSMTTYP_ID AS ORIG_METRIC_ID,
--  TIMESTAMP(M2.MSMT_STRT_DT,M2.MSMT_STRT_TM) AS MEAS_HOUR,
--  CASE WHEN MT.MSMTTYP_NM='Response Time' then MIN(M2.MSMT_MIN_VAL/1000) ELSE MIN(M2.MSMT_MIN_VAL) END AS MIN_VALUE,
--  CASE WHEN MT.MSMTTYP_NM='Response Time' then MAX(M2.MSMT_MAX_VAL/1000) ELSE MAX(M2.MSMT_MAX_VAL) END AS MAX_VALUE,
--  CASE WHEN MT.MSMTTYP_NM='Response Time' then AVG(M2.MSMT_AVG_VAL/1000) ELSE AVG(M2.MSMT_AVG_VAL) END AS AVG_VALUE,
--  SUM(M2.MSMT_TOT_VAL) AS TOTAL_VALUE,
--  MAX(M2.MSMT_SMPL_CNT) AS SAMPLE_COUNT,
--  MAX(M2.MSMT_ERR_CNT) AS ERROR_COUNT
-- FROM
--  TWG.MSMT M2,
--  TWG.CUR_COMP C1,
--  TWG.MSMTTYP MT,
--  SESSION.J2EE_TO_TX_ND J,
--  SESSION.TX_TO_TX_ND TX,
--  SESSION.HOST_TO_TX_ND H
-- WHERE
--  M2.COMP_ID=C1.COMP_ID AND
--  C1.COMPTYP_CD = 'BWM_TX_NODE' AND
--  M2.TMSUM_CD='H' AND
--  M2.MSMTTYP_ID=MT.MSMTTYP_ID AND
--  J.TX_ND_ID=TX.TX_ND_ID AND
--  J.TX_ND_ID=H.TX_ND_ID AND
--  J.TX_ND_ID=M2.COMP_ID
-- GROUP BY
--  M2.MSMT_ID,M2.COMP_ID,M2.MSMTTYP_ID,M2.MSMT_STRT_DT,M2.MSMT_STRT_TM, TX.TX_ID, J.J2EE_ID, H.HOST_ID, MT.MSMTTYP_NM
--;

INSERT INTO BWM.STG_CDW_TX_ND_HR  (CDW_ID,  MSMT_ID, ORIG_TX_ND_ID, ORIG_TX_ID, ORIG_APP_ID, ORIG_HOST_ID, ORIG_METRIC_ID, MEAS_HOUR, MIN_VALUE, MAX_VALUE, AVG_VALUE, TOTAL_VALUE,  SAMPLE_COUNT,  ERROR_COUNT )
 SELECT
  1 AS CDW_ID,
  M1.MSMT_ID,
  M1.COMP_ID AS ORIG_TX_ND_ID,
  TX.TX_ID AS ORIG_TX_ID,
  J.J2EE_ID AS ORIG_APP_ID,
  H.HOST_ID AS ORIG_HOST_ID,
  M1.MSMTTYP_ID AS ORIG_METRIC_ID,
  M1.MEAS_HOUR,
  MIN(M1.MSMT_MIN_VAL) AS MIN_VALUE,
  MAX(M1.MSMT_MAX_VAL)AS MAX_VALUE,
  AVG(M1.MSMT_AVG_VAL) AS AVG_VALUE,
  SUM(M1.MSMT_TOT_VAL) AS TOTAL_VALUE,
  MAX(M1.MSMT_SMPL_CNT) AS SAMPLE_COUNT,
  MAX(M1.MSMT_ERR_CNT) AS ERROR_COUNT
 FROM
  SESSION.TMP_MSMT M1 ,
  BWM.TMP_J2EE_TO_TX_ND J,
  BWM.TMP_TX_TO_TX_ND TX,
  BWM.TMP_HOST_TO_TX_ND H
 WHERE
  J.TX_ND_ID=TX.TX_ND_ID AND
  J.TX_ND_ID=H.TX_ND_ID AND
  J.TX_ND_ID=M1.COMP_ID
 GROUP BY
  M1.MSMT_ID,M1.COMP_ID,M1.MSMTTYP_ID,M1.MEAS_HOUR,TX.TX_ID,J.J2EE_ID,H.HOST_ID,M1.MSMTTYP_NM
;
-------------------------------------------------------------------------------
-- DROP temporary tables when done with them to reclaim space.
-------------------------------------------------------------------------------
--REVISION 20040622
--ADDED TABLE DROP STATEMENTS.

--#IGNORE_ERROR
DROP TABLE BWM.TMP_TX_TO_TX_ND;

--#IGNORE_ERROR
DROP TABLE BWM.TMP_HOST_TO_TX_ND;

--#IGNORE_ERROR
DROP TABLE BWM.TMP_J2EE_TO_TX_ND;

--#IGNORE_ERROR
DROP TABLE BWM.TMP_PROBE_TO_TX_ND;

--#IGNORE_ERROR
DROP TABLE SESSION.TMP_MSMT;

