--------------------------------------------------------------------------
--   OCO Source Materials
--
--   Licensed Materials - Property of IBM
--
--   5724-C02
--
--   (C) Copyright IBM Corp. 2003  All Rights Reserved.
--
--   US Government Users Restricted Rights - Use, duplication or
--   disclosure restricted by GSA ADP Schedule Contract with IBM Corp.
--------------------------------------------------------------------------
--    File Information: src/ReportUI/tedw/tedw_apps_etl/bwm/pkg/v510/etl/sql/bwm_c10_s030_transform_load.db2, tp_tedw, ReportUI_52
--    Revision: 1.56
--    Date: 10/14/03 17:40:21
--------------------------------------------------------------------------
--------------------------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- * handling transactions less than 254 characters to TWG.COMP inserts
--------------------------------------------------------------------------
-----------------------------------------------------------
--Create a temp table with 1 row per BWM_HOST already in
--the CDW
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp_cdw_host (
  host_name VARCHAR(254)
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


INSERT INTO session.tmp_cdw_host
SELECT
    comp_nm AS host_name
FROM
    twg.cur_comp
WHERE
    comptyp_cd in ('IP_HOST','BWM_HOST')
;


-----------------------------------------------------------
--Create a temp table with 1 row per BWM_HOST already in
--the Staging
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp_stage_host(
  host_name VARCHAR(254)
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


INSERT INTO session.tmp_stage_host
SELECT DISTINCT
    host_name AS host_name
FROM
    BWM.STAGE_HOST
;

-----------------------------------------------------------
--Insert all new host compoonents into the twg.comp
-----------------------------------------------------------

INSERT INTO twg.comp(comp_id, comptyp_cd, centr_cd, cust_id, comp_nm,comp_corr_val,comp_strt_dttm,comp_end_dttm,comp_ds)
SELECT
    0 AS Comp_ID,
    case
    when locate('.', t1.host_name) = 0
        then 'BWM_HOST'
        else 'IP_HOST'
    end as comptyp_cd,
    centr.centr_cd AS centr_cd,
    cust.cust_id AS cust_id,
    t1.host_name AS comp_nm,
    '' AS Comp_Corr_Val,
    CURRENT TIMESTAMP - CURRENT TIMEZONE AS comp_start_dttm,
    '9999-01-01-00.00.00.000000' AS comp_end_dttm,
    case
    when locate('.', t1.host_name) = 0
        then 'HOST'
        else 'IP HOST'
    end  AS comp_ds
FROM
  session.tmp_stage_host t1,
  bwm.cust_lookup cust,
  bwm.centr_lookup centr
WHERE
  (cust.value = t1.host_name or cust.value = '@') AND
  (centr.value = t1.host_name or centr.value = '@') AND
  NOT EXISTS (
   SELECT 1
   FROM
     session.tmp_cdw_host t2
   WHERE
     t1.host_name = t2.host_name
 )
;

-------------------------------------
-------------------------------------
--I miss server + domain + node
------------------------------------
------------------------------------
-----------------------------------------------------------
--Parse the keyword ( J2EE or QOS or STI or WinGen )
-----------------------------------------------------------
--------------------------------------------------------------
-- Parse the keyword J2EE, QOS, STI or GenWin into appkey1
--REVISION 20040717 Make this a logged table for index benefit
--------------------------------------------------------------

--#IGNORE_ERROR
DROP TABLE BWM.app1
;

--DECLARE AUXILLARY TABLE  (
CREATE TABLE BWM.app1(
    APPL_NAME VARCHAR(254),
    APPL_ID INTEGER NOT NULL,
    appkey1 VARCHAR(254)NOT NULL,
    PRIMARY KEY (APPL_ID, APPKEY1)
--)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;
);


INSERT INTO BWM.app1
SELECT
    CASE
     WHEN LOCATE('/',APPL_NAME) > 0
     then
     SUBSTR(APPL_NAME, LOCATE('/',APPL_NAME)+1) CONCAT '!!'
     ELSE
      '!!'
     END AS APPL_NAME,
     INTEGER(APPL_ID),
     CASE
     WHEN LOCATE('/',APPL_NAME) > 0
     THEN SUBSTR(APPL_NAME,1,LOCATE('/',APPL_NAME) - 1)
     else APPL_NAME
     END AS appkey1
FROM
 bwm.stage_application;

-----------------------------------------------------------
--Parse the application vendor if J2EE
-----------------------------------------------------------

--select * from BWM.app1;

DECLARE GLOBAL TEMPORARY TABLE app2 (
    APPL_NAME VARCHAR(254),
    APPL_ID INTEGER,
    appkey2 VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;

INSERT INTO session.app2
SELECT
    CASE
     WHEN LOCATE('/',APPL_NAME)  > 0
     then
     SUBSTR(APPL_NAME, LOCATE('/',APPL_NAME)+1)
     ELSE
      '!!'
     END AS APPL_NAME,
     APPL_ID,
     CASE
     WHEN LOCATE('/',APPL_NAME) > 0
     then SUBSTR(APPL_NAME,1,LOCATE('/',APPL_NAME) - 1)
     ELSE SUBSTR(APPL_NAME,1, LOCATE('!!',APPL_NAME) - 1)
     END as appkey2
FROM
 BWM.app1
;

--select * from session.app2;

-----------------------------------------------------------
--Parse the application version if J2EE
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE app3 (
    APPL_NAME VARCHAR(254),
    APPL_ID INTEGER,
    appkey3 VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


INSERT INTO session.app3
SELECT
    CASE
     WHEN LOCATE('/',APPL_NAME) > 0
     then
     SUBSTR(APPL_NAME, LOCATE('/',APPL_NAME)+1)
     ELSE
      '!!'
     END AS APPL_NAME,
     APPL_ID,
     CASE
     WHEN LOCATE('/',APPL_NAME) > 0
     then SUBSTR(APPL_NAME,1,LOCATE('/',APPL_NAME) - 1)
     ELSE SUBSTR(APPL_NAME,1, LOCATE('!!',APPL_NAME) - 1)
     END as appkey3
FROM
 session.app2
  ;
--select * from session.app3;

-----------------------------------------------------------
--Parse the J2EE Cell or Domain
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE app4 (
    APPL_NAME VARCHAR(254),
    APPL_ID INTEGER,
    appkey4 VARCHAR(254)
) WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


INSERT INTO session.app4
SELECT
    CASE
     WHEN LOCATE('/',APPL_NAME) > 0
     then
     SUBSTR(APPL_NAME, LOCATE('/',APPL_NAME)+1)
     ELSE
      '!!'
     END AS APPL_NAME,
     APPL_ID,
     CASE
     WHEN LOCATE('/',APPL_NAME) > 0
     then SUBSTR(APPL_NAME,1,LOCATE('/',APPL_NAME) - 1)
     ELSE SUBSTR(APPL_NAME,1, LOCATE('!!',APPL_NAME) - 1)
     END as appkey4
FROM
 session.app3
  ;
--select * from session.app4;

-----------------------------------------------------------
--Parse the J2EE Node
-----------------------------------------------------------
DECLARE GLOBAL TEMPORARY TABLE app5 (
    APPL_NAME VARCHAR(254),
    APPL_ID INTEGER,
    appkey5 VARCHAR(254)
) WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;



INSERT INTO session.app5
SELECT
    CASE
     WHEN LOCATE('/',APPL_NAME) > 0
     then
     SUBSTR(APPL_NAME, LOCATE('/',APPL_NAME)+1)
     ELSE
      '!!'
     END AS APPL_NAME,
     APPL_ID,
     CASE
     WHEN LOCATE('/',APPL_NAME) > 0
     then SUBSTR(APPL_NAME,1,LOCATE('/',APPL_NAME) - 1)
     ELSE SUBSTR(APPL_NAME,1, LOCATE('!!',APPL_NAME) - 1)
     END as appkey5
FROM
 session.app4
  ;
--select * from session.app5;

-----------------------------------------------------------
--Parse the app server name
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE app6 (
    APPL_NAME VARCHAR(254),
    APPL_ID INTEGER,
    appkey6 VARCHAR(254)
) WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


INSERT INTO session.app6
SELECT
    CASE
     WHEN LOCATE('/',APPL_NAME) > 0
     then
     SUBSTR(APPL_NAME, LOCATE('/',APPL_NAME)+1)
     ELSE
      '!!'
     END AS APPL_NAME,
     APPL_ID,
     CASE
     WHEN LOCATE('/',APPL_NAME) > 0
     then SUBSTR(APPL_NAME,1,LOCATE('/',APPL_NAME) - 1)
     ELSE SUBSTR(APPL_NAME,1, LOCATE('!!',APPL_NAME) - 1)
     END as appkey6
FROM
 session.app5
  ;
--select * from session.app6;


----------------------------------
-- STAGE
----------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp_stage_j2ee(
  j2ee_server VARCHAR(254),
  j2ee_node   VARCHAR(254),
  j2ee_cell   VARCHAR(254),
  j2ee_domain VARCHAR(254),
  j2ee_app_type VARCHAR(254),
  j2ee_app_vers VARCHAR(254),
  j2ee_id INTEGER
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;

--- server + domain - no node - no .*
--- jmg , d126834, weblogic enablement

INSERT INTO session.tmp_stage_j2ee
select
a5.appkey5 as j2ee_server,
'' as j2ee_node,
'' as j2ee_cell,
a4.appkey4 as j2ee_domain,
a2.appkey2 as j2ee_app_type,
a3.appkey3 as j2ee_app_vers,
a1.appl_id as j2ee_id
from
  BWM.app1 a1,
  session.app2 a2,
  session.app3 a3,
  session.app4 a4,
  session.app5 a5,
  session.app6 a6
where
  a2.appkey2='WebLogic' and
  a1.appkey1='J2EE' and
  a1.appl_id=a2.appl_id and
  a1.appl_id=a3.appl_id and
  a1.appl_id=a4.appl_id and
  a1.appl_id=a5.appl_id and
  a1.appl_id=a6.appl_id and
  a2.appkey2 != '' and
  a3.appkey3 != '' and
  a2.appkey2 != '.*'
group by
a5.appkey5,
a4.appkey4,
a2.appkey2,
a3.appkey3,
a1.appl_id
;


--select * from session.tmp_stage_j2ee;
-- server + node + domain - no .* - Websphere 4.x

INSERT INTO session.tmp_stage_j2ee
select
a6.appkey6 as j2ee_server,
a5.appkey5 as j2ee_node,
'' as j2ee_cell,
substr(a4.appkey4,locate('Domain:',a4.appkey4) + 7, length(a4.appkey4)) as j2ee_domain,
a2.appkey2 as j2ee_app_type,
a3.appkey3 as j2ee_app_vers,
a1.appl_id as j2ee_id
from
  BWM.app1 a1,
  session.app2 a2,
  session.app3 a3,
  session.app4 a4,
  session.app5 a5,
  session.app6 a6
where
  a1.appkey1='J2EE' and
  a1.appl_id=a2.appl_id and
  a1.appl_id=a3.appl_id and
  a1.appl_id=a4.appl_id and
  a1.appl_id=a5.appl_id and
  a1.appl_id=a6.appl_id and
  a4.appkey4 != '' and
  a3.appkey3 != '' and
  a3.appkey3 like '4.%' and
  a2.appkey2='WebSphere' and
  a2.appkey2 != '' and
  a2.appkey2 != '.*'
group by
a6.appkey6,
a5.appkey5,
a4.appkey4,
a2.appkey2,
a3.appkey3,
a1.appl_id
;

--select * from session.tmp_stage_j2ee;
-- server + node + cell - no .* - not Websphere 4.x (5.x or more)

INSERT INTO session.tmp_stage_j2ee
select
a6.appkey6 as j2ee_server,
a5.appkey5 as j2ee_node,
a4.appkey4 as j2ee_cell,
'' as j2ee_domain,
a2.appkey2 as j2ee_app_type,
a3.appkey3 as j2ee_app_vers,
a1.appl_id as j2ee_id
from
  BWM.app1 a1,
  session.app2 a2,
  session.app3 a3,
  session.app4 a4,
  session.app5 a5,
  session.app6 a6
where
  a1.appkey1='J2EE' and
  a1.appl_id=a2.appl_id and
  a1.appl_id=a3.appl_id and
  a1.appl_id=a4.appl_id and
  a1.appl_id=a5.appl_id and
  a1.appl_id=a6.appl_id and
  a4.appkey4 != '' and
  a3.appkey3 != '' and
  a2.appkey2 != '' and
  a3.appkey3 not like '4.%' and
  a2.appkey2='WebSphere' and
  a2.appkey2 != '.*'
group by
a6.appkey6,
a5.appkey5,
a4.appkey4,
a2.appkey2,
a3.appkey3,
a1.appl_id
;

--select * from session.tmp_stage_j2ee;
-- server + node - no cell - no .*

INSERT INTO session.tmp_stage_j2ee
select
a6.appkey6 as j2ee_server,
a5.appkey5 as j2ee_node,
'' as j2ee_cell,
'' as j2ee_domain,
a2.appkey2 as j2ee_app_type,
a3.appkey3 as j2ee_app_vers,
a1.appl_id as j2ee_id
from
  BWM.app1 a1,
  session.app2 a2,
  session.app3 a3,
  session.app4 a4,
  session.app5 a5,
  session.app6 a6
where
  a1.appkey1='J2EE' and
  a1.appl_id=a2.appl_id and
  a1.appl_id=a3.appl_id and
  a1.appl_id=a4.appl_id and
  a1.appl_id=a5.appl_id and
  a1.appl_id=a6.appl_id and
  a4.appkey4 != '' and
  a3.appkey3 != '' and
  a2.appkey2 = '' and
  a2.appkey2 != '.*'
group by
a6.appkey6,
a5.appkey5,
a2.appkey2,
a3.appkey3,
a1.appl_id
;

--select * from session.tmp_stage_j2ee;
-- server - no cell -no domain - no node - no .*

INSERT INTO session.tmp_stage_j2ee
select
a6.appkey6 as j2ee_server,
'' as j2ee_node,
'' as j2ee_cell,
'' as j2ee_domain,
a2.appkey2 as j2ee_app_type,
a3.appkey3 as j2ee_app_vers,
a1.appl_id as j2ee_id
from
  BWM.app1 a1,
  session.app2 a2,
  session.app3 a3,
  session.app4 a4,
  session.app5 a5,
  session.app6 a6
where
  a1.appkey1='J2EE' and
  a1.appl_id=a2.appl_id and
  a1.appl_id=a3.appl_id and
  a1.appl_id=a4.appl_id and
  a1.appl_id=a5.appl_id and
  a1.appl_id=a6.appl_id and
  a4.appkey4 != '' and
  a3.appkey3 = '' and
  a2.appkey2 = '' and
  a2.appkey2 != '.*'
group by
a6.appkey6,
a2.appkey2,
a3.appkey3,
a1.appl_id
;

-- .*
-- d126707, jmg, 20040405
-- Omit the root set of J2EE servers

--INSERT INTO session.tmp_stage_j2ee
--select
-- '.*' as j2ee_server,
--'N/A' as j2ee_node,
--'N/A' as j2ee_cell,
--'N/A' as j2ee_domain,
--'N/A' as j2ee_app_type,
--'N/A' as j2ee_app_vers,
--a1.appl_id as j2ee_id
--from
--  BWM.app1 a1,
--  session.app6 a6
--where
--  a1.appkey1='J2EE' and
--  a1.appl_name='.*!!'
--;

--select
--substr(j2ee_server,1,15) as j2ee_server,
--substr(j2ee_node,1,15) as j2ee_node,
--substr(j2ee_cell,1,15) as j2ee_cell,
--substr(j2ee_domain,1,45) as j2ee_domain,
--substr(j2ee_app_type,1,15) as j2ee_app_type,
--substr(j2ee_app_vers,1,15) as j2ee_app_vers
--from session.tmp_stage_j2ee;

----------------------------------
-- CDW
----------------------------------
DECLARE GLOBAL TEMPORARY TABLE tmp_cdw_j2ee(
  j2ee_server_id INTEGER,
  j2ee_server VARCHAR(254),
  j2ee_node   VARCHAR(254),
  j2ee_cell   VARCHAR(254),
  j2ee_domain VARCHAR(254),
  j2ee_app_type VARCHAR(254),
  j2ee_app_vers VARCHAR(254)
) WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;

-- server + domain  - no node - no .*

INSERT INTO session.tmp_cdw_j2ee
SELECT
c1.comp_id as j2ee_server_id,
c1.comp_nm as  j2ee_server,
'' as  j2ee_node,
''  as j2ee_cell,
c2.comp_nm  as j2ee_domain,
ca1.compattr_val  as j2ee_app_type,
ca2.compattr_val  as j2ee_app_vers
FROM
    twg.cur_comp c1,
    twg.cur_compreln r1,
    twg.cur_comp c2,
    twg.cur_compattr ca1,
    twg.cur_compattr ca2
WHERE
    c1.comptyp_cd = 'J2EE_SERVER' and
    r1.comp_source_id = c2.comp_id and
    c2.comptyp_cd = 'J2EE_DOMAIN' and
    r1.comp_target_id = c1.comp_id and
    r1.relntyp_cd='PCHILD' and
    ca1.comp_id=c1.comp_id and
    ca1.attrtyp_cd='MANUFACTURER' and
    ca2.attrtyp_cd='VERSION' and
    ca2.comp_id=c1.comp_id and
    not exists (
    select
     1
    from
      twg.cur_comp c3,
      twg.cur_compreln r2
    where
      r2.relntyp_cd ='PCHILD' and
      r2.comp_source_id = c2.comp_id and
      r2.comp_target_id = c3.comp_id and
      c3.comptyp_cd ='J2EE_NODE'
      ) and
     c1.comp_nm != '.*'
group by
c1.comp_id,
c1.comp_nm,
c2.comp_nm,
ca1.compattr_val,
ca2.compattr_val
;

-- server + node + cell - no .*

INSERT INTO session.tmp_cdw_j2ee
SELECT
c1.comp_id as j2ee_server_id,
c1.comp_nm as  j2ee_server,
c2.comp_nm as  j2ee_node,
c3.comp_nm as j2ee_cell,
''  as j2ee_domain,
ca1.compattr_val  as j2ee_app_type,
ca2.compattr_val  as j2ee_app_vers
FROM
    twg.cur_comp c1,
    twg.cur_compreln r1,
    twg.cur_comp c2,
    twg.cur_comp c3,
    twg.cur_compreln r2,
    twg.cur_compattr ca1,
    twg.cur_compattr ca2
WHERE
    c1.comptyp_cd = 'J2EE_SERVER' and
    r1.comp_source_id = c2.comp_id and
    c2.comptyp_cd = 'J2EE_NODE' and
    r1.comp_target_id = c1.comp_id and
    r1.relntyp_cd ='PCHILD' and
    r2.relntyp_cd ='PCHILD' and
    r2.comp_source_id = c3.comp_id and
    r2.comp_target_id =  c2.comp_id and
    c3.comptyp_cd ='J2EE_CELL' and
    c1.comp_nm != '.*' and
    ca1.comp_id=c1.comp_id and
    ca1.attrtyp_cd='MANUFACTURER' and
    ca2.attrtyp_cd='VERSION' and
    ca2.comp_id=c1.comp_id
group by
c1.comp_id,
c1.comp_nm,
c2.comp_nm,
c3.comp_nm,
ca1.compattr_val,
ca2.compattr_val
    ;

-- server + node - no cell - no .*

INSERT INTO session.tmp_cdw_j2ee
SELECT
c1.comp_id as j2ee_server_id,
c1.comp_nm as  j2ee_server,
c2.comp_nm as  j2ee_node,
''  as j2ee_cell,
''  as j2ee_domain,
ca1.compattr_val  as j2ee_app_type,
ca2.compattr_val  as j2ee_app_vers
FROM
    twg.cur_comp c1,
    twg.cur_compreln r1,
    twg.cur_comp c2,
    twg.cur_compattr ca1,
    twg.cur_compattr ca2
WHERE
    c1.comptyp_cd = 'J2EE_SERVER' and
    r1.comp_source_id = c2.comp_id and
    c2.comptyp_cd = 'J2EE_NODE' and
    r1.comp_target_id = c1.comp_id and
    r1.relntyp_cd ='PCHILD' and
    ca1.comp_id=c1.comp_id and
    ca1.attrtyp_cd='MANUFACTURER' and
    ca2.attrtyp_cd='VERSION' and
    ca2.comp_id=c1.comp_id and
    not exists (
    select
     1
    from
      twg.cur_comp c3,
      twg.cur_compreln r2
    where
      r2.relntyp_cd ='PCHILD' and
      r2.comp_source_id = c3.comp_id and
      r2.comp_target_id = c2.comp_id and
      c3.comptyp_cd ='J2EE_CELL'
      ) and
      c1.comp_nm != '.*'
group by
c1.comp_id,
c1.comp_nm,
c2.comp_nm,
ca1.compattr_val,
ca2.compattr_val
;


-- server - no cell -no domain - no node - no .*

INSERT INTO session.tmp_cdw_j2ee
SELECT
c1.comp_id as j2ee_server_id,
c1.comp_nm as  j2ee_server,
''  as  j2ee_node,
''  as j2ee_cell,
''  as j2ee_domain,
ca1.compattr_val  as j2ee_app_type,
ca2.compattr_val  as j2ee_app_vers
FROM
    twg.cur_comp c1,
    twg.cur_compattr ca1,
    twg.cur_compattr ca2
WHERE
    c1.comptyp_cd = 'J2EE_SERVER' and
    ca1.comp_id=c1.comp_id and
    ca1.attrtyp_cd='MANUFACTURER' and
    ca2.attrtyp_cd='VERSION' and
    ca2.comp_id=c1.comp_id and
    not exists (
    select
     1
    from
     twg.cur_compreln r1,
     twg.cur_comp c2
    where
     r1.comp_source_id = c2.comp_id and
     c2.comptyp_cd = 'J2EE_NODE' and
     r1.comp_target_id = c1.comp_id and
     r1.relntyp_cd ='PCHILD'
     ) and
    not exists (
    select
     1
    from
      twg.cur_comp c3,
      twg.cur_compreln r2
    where
      r2.relntyp_cd ='PCHILD' and
      r2.comp_source_id = c3.comp_id and
      r2.comp_target_id = c1.comp_id and
      c3.comptyp_cd ='J2EE_DOMAIN'
      ) and
      c1.comp_nm != '.*'
group by
c1.comp_id,
c1.comp_nm,
ca1.compattr_val,
ca2.compattr_val
;

-- .*
-- .*
-- d126707, jmg, 20040405
-- Omit the root set of J2EE servers

--INSERT INTO session.tmp_cdw_j2ee
--SELECT
--c1.comp_id as j2ee_server_id,
--'.*' as j2ee_server,
--'N/A' as j2ee_node,
--'N/A' as j2ee_cell,
--'N/A' as j2ee_domain,
--'N/A' as j2ee_app_type,
--'N/A' as j2ee_app_vers
--FROM
--    twg.cur_comp c1
--WHERE
--    c1.comptyp_cd = 'J2EE_SERVER' and
--    c1.comp_nm = '.*'
--group by
--c1.comp_id
--;

--select
--substr(j2ee_server,1,25) as j2ee_server,
--substr(j2ee_node,1,15) as j2ee_node,
--substr(j2ee_cell,1,15) as j2ee_cell,
--substr(j2ee_domain,1,45) as j2ee_domain,
--substr(j2ee_app_type,1,15) as j2ee_app_type,
--substr(j2ee_app_vers,1,15) as j2ee_app_vers
--from session.tmp_cdw_j2ee;

INSERT INTO twg.comp(comp_id, comptyp_cd, centr_cd, cust_id, comp_nm,comp_corr_id,comp_corr_val,comp_strt_dttm,comp_end_dttm,comp_ds)
SELECT
    0 AS comp_id,
    'J2EE_SERVER' AS comptyp_cd,
    centr.centr_cd AS centr_cd,
    cust.cust_id AS cust_id,
    t1.j2ee_server AS comp_nm,
    t1.j2ee_id as comp_corr_id,
    t1.j2ee_app_type concat '!!' concat t1.j2ee_app_vers as comp_corr_val,
    CURRENT TIMESTAMP - CURRENT TIMEZONE AS comp_start_dttm,
    '9999-01-01-00.00.00.000000' AS comp_end_dttm,
    '' AS comp_ds
FROM
    session.tmp_stage_j2ee t1,
    bwm.stage_node n1,
    bwm.stage_host h1,
    bwm.cust_lookup cust,
    bwm.centr_lookup centr
WHERE
  t1.j2ee_id = INTEGER(n1.appl_id )and
  n1.host_id = h1.host_id and
  (cust.value = h1.host_name OR cust.value = '@') AND
  (centr.value = h1.host_name OR centr.value = '@') AND
  NOT EXISTS (
   SELECT 1
   FROM
     session.tmp_cdw_j2ee t2
   WHERE
     t1.j2ee_server = t2.j2ee_server and
     t1.j2ee_node =  t2.j2ee_node and
     t1.j2ee_cell = t2.j2ee_cell and
     t1.j2ee_domain = t2.j2ee_domain and
     t1.j2ee_app_type = t2.j2ee_app_type and
     t1.j2ee_app_vers = t2.j2ee_app_vers
     )
   GROUP BY
  t1.j2ee_server, t1.j2ee_id ,t1.j2ee_app_type, t1.j2ee_app_vers, centr.centr_cd, cust.cust_id
;

INSERT INTO twg.comp(comp_id, comptyp_cd, centr_cd, cust_id, comp_nm,comp_corr_id,comp_strt_dttm,comp_end_dttm,comp_ds)
SELECT
    0 AS Comp_ID,
    'J2EE_NODE' AS comptyp_cd,
    centr.centr_cd AS centr_cd,
    cust.cust_id AS cust_id,
    t1.j2ee_node AS comp_nm,
    t1.j2ee_id  AS Comp_Corr_id,
    CURRENT TIMESTAMP - CURRENT TIMEZONE AS comp_start_dttm,
    '9999-01-01-00.00.00.000000' AS comp_end_dttm,
    '' AS comp_ds
FROM    session.tmp_stage_j2ee t1,
	bwm.stage_node n1,
    	bwm.stage_host h1,
        bwm.cust_lookup cust,
        bwm.centr_lookup centr
WHERE
  t1.j2ee_id = INTEGER(n1.appl_id) and
  t1.j2ee_node != '' and
  n1.host_id = h1.host_id and
  (cust.value = h1.host_name OR cust.value = '@') AND
  (centr.value = h1.host_name OR centr.value = '@') AND
  NOT EXISTS (
   SELECT 1
   FROM
     session.tmp_cdw_j2ee t2
   WHERE
     t1.j2ee_server = t2.j2ee_server and
     t1.j2ee_node =  t2.j2ee_node and
     t1.j2ee_cell = t2.j2ee_cell and
     t1.j2ee_domain = t2.j2ee_domain and
     t1.j2ee_app_type = t2.j2ee_app_type and
     t1.j2ee_app_vers = t2.j2ee_app_vers
     )
GROUP BY
  t1.j2ee_node, j2ee_id, centr.centr_cd, cust.cust_id
;

INSERT INTO twg.comp(comp_id, comptyp_cd, centr_cd, cust_id, comp_nm,comp_corr_id,comp_strt_dttm,comp_end_dttm,comp_ds)
SELECT
    0 as comp_id,
    'J2EE_CELL' as comptyp_cd,
    centr.centr_cd AS centr_cd,
    cust.cust_id AS cust_id,
    t1.j2ee_cell AS comp_nm,
    t1.j2ee_id  AS Comp_Corr_id,
    CURRENT TIMESTAMP - CURRENT TIMEZONE AS comp_start_dttm,
    '9999-01-01-00.00.00.000000' AS comp_end_dttm,
    '' AS comp_ds
FROM
	session.tmp_stage_j2ee t1,
  	bwm.stage_node n1,
    	bwm.stage_host h1,
        bwm.cust_lookup cust,
        bwm.centr_lookup centr
WHERE
  t1.j2ee_id = INTEGER(n1.appl_id) and
  t1.j2ee_cell != '' and
  n1.host_id = h1.host_id and
  (cust.value = h1.host_name OR cust.value = '@') AND
  (centr.value = h1.host_name OR centr.value = '@') AND
  NOT EXISTS (
   SELECT 1
   FROM
     session.tmp_cdw_j2ee t2
   WHERE
     t1.j2ee_server = t2.j2ee_server and
     t1.j2ee_node =  t2.j2ee_node and
     t1.j2ee_cell = t2.j2ee_cell and
     t1.j2ee_domain = t2.j2ee_domain and
     t1.j2ee_app_type = t2.j2ee_app_type and
     t1.j2ee_app_vers = t2.j2ee_app_vers
     )
GROUP BY
  t1.j2ee_cell, t1.j2ee_id,  centr.centr_cd, cust.cust_id
;

INSERT INTO twg.comp(comp_id, comptyp_cd, centr_cd, cust_id, comp_nm,comp_corr_id,comp_strt_dttm,comp_end_dttm,comp_ds)
SELECT
    0 as comp_id,
    'J2EE_DOMAIN' as comptyp_cd,
    centr.centr_cd AS centr_cd,
    cust.cust_id AS cust_id,
    t1.j2ee_domain AS comp_nm,
    t1.j2ee_id  AS Comp_Corr_id,
    CURRENT TIMESTAMP - CURRENT TIMEZONE AS comp_start_dttm,
    '9999-01-01-00.00.00.000000' AS comp_end_dttm,
    '' AS comp_ds
FROM
	session.tmp_stage_j2ee t1,
  	bwm.stage_node n1,
    	bwm.stage_host h1,
        bwm.cust_lookup cust,
        bwm.centr_lookup centr
WHERE
  t1.j2ee_id = INTEGER(n1.appl_id) and
  t1.j2ee_domain !='' and
  n1.host_id = h1.host_id and
  (cust.value = h1.host_name OR cust.value = '@') AND
  (centr.value = h1.host_name OR centr.value = '@') AND
  NOT EXISTS (
   SELECT 1
   FROM
     session.tmp_cdw_j2ee t2
   WHERE
     t1.j2ee_server = t2.j2ee_server and
     t1.j2ee_node =  t2.j2ee_node and
     t1.j2ee_cell = t2.j2ee_cell and
     t1.j2ee_domain = t2.j2ee_domain and
     t1.j2ee_app_type = t2.j2ee_app_type and
     t1.j2ee_app_vers = t2.j2ee_app_vers
     )
GROUP BY
  t1.j2ee_domain, t1.j2ee_id,  centr.centr_cd, cust.cust_id
;

-----------------------------------------------------------
-- Add CompReln for J2EE Node to J2EE Server (PCHILD)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm)
SELECT DISTINCT
    0 AS Compreln_id,
    c2.comp_id AS comp_source_id,
    c1.comp_id AS comp_target_id,
    'PCHILD' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2
WHERE
    c1.CompTyp_Cd = 'J2EE_SERVER' and
    c2.CompTyp_Cd = 'J2EE_NODE' and
    c1.comp_corr_id = c2.comp_corr_id AND
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c2.comp_id = c3.comp_source_id and
    c1.comp_id = c3.comp_target_id and
    c3.relntyp_cd='PCHILD')
;

-----------------------------------------------------------
-- Add CompReln for J2EE DOMAIN to J2EE NODE (PCHILD)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm)
SELECT DISTINCT
    0 AS Compreln_id,
    c2.comp_id AS comp_source_id,
    c1.comp_id AS comp_target_id,
    'PCHILD' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2
WHERE
    c1.CompTyp_Cd = 'J2EE_NODE' AND
    c2.CompTyp_Cd = 'J2EE_DOMAIN' AND
    c1.comp_corr_id = c2.comp_corr_id AND
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c2.comp_id = c3.comp_source_id AND
    c1.comp_id = c3.comp_target_id AND
    c3.relntyp_cd='PCHILD')
;

-----------------------------------------------------------
-- Add CompReln for J2EE CELL to J2EE NODE (PCHILD)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm)
SELECT DISTINCT
    0 AS Compreln_id,
    c2.comp_id AS comp_source_id,
    c1.comp_id AS comp_target_id,
    'PCHILD' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2
WHERE
    c1.CompTyp_Cd = 'J2EE_NODE' AND
    c2.CompTyp_Cd = 'J2EE_CELL' AND
    c1.comp_corr_id = c2.comp_corr_id AND
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c2.comp_id = c3.comp_source_id
    AND c1.comp_id = c3.comp_target_id
    AND c3.relntyp_cd='PCHILD')
;

-----------------------------------------------------------
-- Add CompReln for J2EE DOMAIN to J2EE SERVER (PCHILD)
-- d126834, jmg, 20040422
-- This relationship is only valid for weblogic
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm)
SELECT DISTINCT
    0 AS Compreln_id,
    c2.comp_id AS comp_source_id,
    c1.comp_id AS comp_target_id,
    'PCHILD' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2
WHERE
    c1.CompTyp_Cd = 'J2EE_SERVER' AND
    c2.CompTyp_Cd = 'J2EE_DOMAIN' AND
    c1.comp_corr_id = c2.comp_corr_id AND
    c1.Comp_corr_val like 'WebLogic%' AND
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c2.comp_id = c3.comp_source_id AND
    c1.comp_id = c3.comp_target_id AND
    c3.relntyp_cd='PCHILD')
;

--------------------------------------------------------
-- Recreate a temporary table with all the new J2EE_SERVER
-- inserted in TWG.COMP
---------------------------------------------------------
DECLARE GLOBAL TEMPORARY TABLE tmp2_cdw_j2ee(
  j2ee_server_id INTEGER,
  j2ee_server VARCHAR(254),
  j2ee_node   VARCHAR(254),
  j2ee_cell   VARCHAR(254),
  j2ee_domain VARCHAR(254),
  j2ee_app_type VARCHAR(254),
  j2ee_app_vers VARCHAR(254)
) WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;

-- server + domain  - no node - no .*

INSERT INTO session.tmp2_cdw_j2ee
SELECT
c1.comp_id as j2ee_server_id,
c1.comp_nm as  j2ee_server,
'' as  j2ee_node,
''  as j2ee_cell,
c2.comp_nm  as j2ee_domain,
substr(c1.comp_corr_val,1,locate('!!', c1.comp_corr_val)- 1) as j2ee_app_type,
substr(c1.comp_corr_val,locate('!!', c1.comp_corr_val) + 2,length(c1.comp_corr_val ) - locate('!!', c1.comp_corr_val)) as j2ee_app_vers
FROM
    twg.cur_comp c1,
    twg.cur_compreln r1,
    twg.cur_comp c2
WHERE
    c1.comptyp_cd = 'J2EE_SERVER' and
    r1.comp_source_id = c2.comp_id and
    c2.comptyp_cd = 'J2EE_DOMAIN' and
    r1.comp_target_id = c1.comp_id and
    r1.relntyp_cd='PCHILD' and
    not exists (
    select
     1
    from
      twg.cur_comp c3,
      twg.cur_compreln r2
    where
      r2.relntyp_cd ='PCHILD' and
      r2.comp_source_id = c2.comp_id and
      r2.comp_target_id = c3.comp_id and
      c3.comptyp_cd ='J2EE_NODE'
      ) and
     c1.comp_nm != '.*'
group by
c1.comp_id, c1.comp_nm,c2.comp_nm, c1.comp_corr_val
;

--select * from session.tmp2_cdw_j2ee;

-- server + node + cell - no .*

INSERT INTO session.tmp2_cdw_j2ee
SELECT
c1.comp_id as j2ee_server_id,
c1.comp_nm as  j2ee_server,
c2.comp_nm as  j2ee_node,
c3.comp_nm as j2ee_cell,
''  as j2ee_domain,
substr(c1.comp_corr_val,1,locate('!!', c1.comp_corr_val)- 1) as j2ee_app_type,
substr(c1.comp_corr_val,locate('!!', c1.comp_corr_val) + 2,length(c1.comp_corr_val ) - locate('!!', c1.comp_corr_val)) as j2ee_app_vers
FROM
    twg.cur_comp c1,
    twg.cur_compreln r1,
    twg.cur_comp c2,
    twg.cur_comp c3,
    twg.cur_compreln r2
WHERE
    c1.comptyp_cd = 'J2EE_SERVER' and
    r1.comp_source_id = c2.comp_id and
    c2.comptyp_cd = 'J2EE_NODE' and
    r1.comp_target_id = c1.comp_id and
    r1.relntyp_cd ='PCHILD' and
    r2.relntyp_cd ='PCHILD' and
    r2.comp_source_id = c3.comp_id and
    r2.comp_target_id =  c2.comp_id and
    c3.comptyp_cd ='J2EE_CELL' and
    c1.comp_nm != '.*'
group by
c1.comp_id, c1.comp_nm, c2.comp_nm, c3.comp_nm,c1.comp_corr_val
;

--select * from session.tmp2_cdw_j2ee;

-- server + node - no cell - no .*

INSERT INTO session.tmp2_cdw_j2ee
SELECT
c1.comp_id as j2ee_server_id,
c1.comp_nm as  j2ee_server,
c2.comp_nm as  j2ee_node,
''  as j2ee_cell,
''  as j2ee_domain,
substr(c1.comp_corr_val,1,locate('!!', c1.comp_corr_val)- 1) as j2ee_app_type,
substr(c1.comp_corr_val,locate('!!', c1.comp_corr_val) + 2,length(c1.comp_corr_val ) - locate('!!', c1.comp_corr_val)) as j2ee_app_vers
FROM
    twg.cur_comp c1,
    twg.cur_compreln r1,
    twg.cur_comp c2
WHERE
    c1.comptyp_cd = 'J2EE_SERVER' and
    r1.comp_source_id = c2.comp_id and
    c2.comptyp_cd = 'J2EE_NODE' and
    r1.comp_target_id = c1.comp_id and
    r1.relntyp_cd ='PCHILD' and
    not exists (
    select
     1
    from
      twg.cur_comp c3,
      twg.cur_compreln r2
    where
      r2.relntyp_cd ='PCHILD' and
      r2.comp_source_id = c3.comp_id and
      r2.comp_target_id = c2.comp_id and
      c3.comptyp_cd ='J2EE_CELL'
      ) and
      c1.comp_nm != '.*'
group by
c1.comp_id, c1.comp_nm, c2.comp_nm,c1.comp_corr_val
;

--select * from session.tmp2_cdw_j2ee;

-- server - no cell -no domain - no node - no .*

INSERT INTO session.tmp2_cdw_j2ee
SELECT
c1.comp_id as j2ee_server_id,
c1.comp_nm as  j2ee_server,
''  as  j2ee_node,
''  as j2ee_cell,
''  as j2ee_domain,
substr(c1.comp_corr_val,1,locate('!!', c1.comp_corr_val)- 1) as j2ee_app_type,
substr(c1.comp_corr_val,locate('!!', c1.comp_corr_val) + 2,length(c1.comp_corr_val ) - locate('!!', c1.comp_corr_val)) as j2ee_app_vers
FROM
    twg.cur_comp c1
    WHERE
    c1.comptyp_cd = 'J2EE_SERVER' and
    not exists (
    select
     1
    from
     twg.cur_compreln r1,
     twg.cur_comp c2
    where
     r1.comp_source_id = c2.comp_id and
     c2.comptyp_cd = 'J2EE_NODE' and
     r1.comp_target_id = c1.comp_id and
     r1.relntyp_cd ='PCHILD'
     ) and
    not exists (
    select
     1
    from
      twg.cur_comp c3,
      twg.cur_compreln r2
    where
      r2.relntyp_cd ='PCHILD' and
      r2.comp_source_id = c3.comp_id and
      r2.comp_target_id = c1.comp_id and
      c3.comptyp_cd ='J2EE_DOMAIN'
      ) and
      c1.comp_nm != '.*'
group by
c1.comp_id, c1.comp_nm, c1.comp_corr_val
;

--select * from session.tmp2_cdw_j2ee;

-- .*
-- d126707, jmg, 20040405
-- Omit the root set of J2EE servers

--INSERT INTO session.tmp2_cdw_j2ee
--SELECT
--c1.comp_id as j2ee_server_id,
--'.*' as j2ee_server,
--'N/A' as j2ee_node,
--'N/A' as j2ee_cell,
--'N/A' as j2ee_domain,
--'N/A'  as j2ee_app_type,
--'N/A' as j2ee_app_vers
--FROM
--    twg.cur_comp c1
--WHERE
--    c1.comptyp_cd = 'J2EE_SERVER' and
--    c1.comp_nm = '.*'
--group by
--c1.comp_id
--;

--select * from session.tmp2_cdw_j2ee;

---------------------------------------------------------
--- Add Version as a Component Attribute
-- of the J2EE_SERVER
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_j2ee_version(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_j2ee_version
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'J2EE_SERVER' and
    ca.attrtyp_cd = 'VERSION' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_j2ee_version (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_j2ee_version
select
 c1.j2ee_server_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_j2ee c1 left outer join session.tmp1_j2ee_version ca1
 on ( c1.j2ee_server_id = ca1.comp_id)
;

-- select * from session.tmp2_j2ee_version;

 insert into twg.compattr(compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.j2ee_server_id as comp_id,
 'VERSION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 s1.j2ee_app_vers as CompAttr_Val
from
 session.tmp_stage_j2ee s1,
 session.tmp2_cdw_j2ee c1,
 session.tmp2_j2ee_version ca1
where
  s1.j2ee_server = c1.j2ee_server and
  s1.j2ee_node =  c1.j2ee_node and
  s1.j2ee_cell = c1.j2ee_cell and
  s1.j2ee_domain = c1.j2ee_domain and
  s1.j2ee_app_type = c1.j2ee_app_type and
  s1.j2ee_app_vers = c1.j2ee_app_vers and
  ca1.comp_id=c1.j2ee_server_id and
  ca1.last_value is null
group by
  c1.j2ee_server_id, s1.j2ee_app_vers
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.j2ee_server_id as comp_id,
 'VERSION' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 s1.j2ee_app_vers as CompAttr_Val
from
 session.tmp_stage_j2ee s1,
 session.tmp2_cdw_j2ee c1,
 session.tmp2_j2ee_version ca1
where
  s1.j2ee_server = c1.j2ee_server and
  s1.j2ee_node =  c1.j2ee_node and
  s1.j2ee_cell = c1.j2ee_cell and
  s1.j2ee_domain = c1.j2ee_domain and
  s1.j2ee_app_type = c1.j2ee_app_type and
  s1.j2ee_app_vers = c1.j2ee_app_vers and
  ca1.last_value is not null and
  ca1.comp_id=c1.j2ee_server_id and
  ca1.last_value != s1.j2ee_app_vers
group by
  c1.j2ee_server_id,  s1.j2ee_app_vers
;

--select * from twg.compattr;

---------------------------------------------------------
--- Add Vendor as a Component Attribute
-- of the J2EE_SERVER
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_j2ee_vendor(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_j2ee_vendor
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'J2EE_SERVER' and
    ca.attrtyp_cd = 'MANUFACTURER' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_j2ee_vendor (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_j2ee_vendor
select
 c1.j2ee_server_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_j2ee c1 left outer join session.tmp1_j2ee_vendor ca1
 on ( c1.j2ee_server_id = ca1.comp_id)
;


 insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.j2ee_server_id as comp_id,
 'MANUFACTURER' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 s1.j2ee_app_type as CompAttr_Val
from
 session.tmp_stage_j2ee s1,
 session.tmp2_cdw_j2ee c1,
 session.tmp2_j2ee_vendor ca1
where
  s1.j2ee_server = c1.j2ee_server and
  s1.j2ee_node =  c1.j2ee_node and
  s1.j2ee_cell = c1.j2ee_cell and
  s1.j2ee_domain = c1.j2ee_domain and
  s1.j2ee_app_type = c1.j2ee_app_type and
  s1.j2ee_app_vers = c1.j2ee_app_vers and
  ca1.comp_id=c1.j2ee_server_id and
  ca1.last_value is null
group by
  c1.j2ee_server_id, s1.j2ee_app_type
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.j2ee_server_id as comp_id,
 'MANUFACTURER' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 s1.j2ee_app_type as CompAttr_Val
from
 session.tmp_stage_j2ee s1,
 session.tmp2_cdw_j2ee c1,
 session.tmp2_j2ee_vendor ca1
where
  s1.j2ee_server = c1.j2ee_server and
  s1.j2ee_node =  c1.j2ee_node and
  s1.j2ee_cell = c1.j2ee_cell and
  s1.j2ee_domain = c1.j2ee_domain and
  s1.j2ee_app_type = c1.j2ee_app_type and
  s1.j2ee_app_vers = c1.j2ee_app_vers and
  ca1.last_value is not null and
  ca1.comp_id=c1.j2ee_server_id and
  ca1.last_value != s1.j2ee_app_type
group by
  c1.j2ee_server_id,  s1.j2ee_app_type
;

--select * from twg.compattr;

-----------------------------------------------------------
-- Create a temp table with 1 row per Probe
-- already in the CDW
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp_cdw_probe(
    probe    	 VARCHAR(254),
    probe_host	 VARCHAR(254),
    probe_id 	 INTEGER
) WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;



INSERT INTO session.tmp_cdw_probe
SELECT
   comp_nm AS probe,
   comp_corr_val AS probe_host,
   comp_id AS probe_id
FROM
    twg.cur_comp
WHERE
    comptyp_cd = 'BWM_PROBE'
;


-----------------------------------------------------------
--Create a temp table with 1 row per Probe
--already in the Staging
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp_stage_probe(
  probe 	VARCHAR(254),
  probe_host 	VARCHAR(254),
  probe_id	INTEGER
  )
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


INSERT INTO session.tmp_stage_probe
SELECT
 a1.appkey1 AS probe,
 h1.host_name as probe_host,
 a1.appl_id as probe_id
FROM
 BWM.app1 a1,
 bwm.stage_node n1,
 bwm.stage_host h1
WHERE
 a1.appkey1 in ('QOS', 'STI','GenWin') and
 a1.appl_id = INTEGER(n1.appl_id) and
 n1.host_id = h1.host_id
;

-----------------------------------------------------------
-- Insert Probe components in to twg.comp
-- comp_corr_id is the unique id to identify a Probe
-- comp_corr_val is the host name linked with this Probe
-----------------------------------------------------------

INSERT INTO twg.comp (comp_id, comptyp_cd, centr_cd, cust_id, comp_nm,comp_corr_id,comp_corr_val,comp_strt_dttm,comp_end_dttm,comp_ds)
SELECT
    0 AS comp_id,
    'BWM_PROBE' AS comptyp_cd,
    centr.centr_cd AS centr_cd,
    cust.cust_id AS cust_id,
    t1.probe AS comp_nm,
    t1.probe_id as comp_corr_id,
    t1.probe_host AS Comp_Corr_Val,
    CURRENT TIMESTAMP - CURRENT TIMEZONE AS comp_strt_dttm,
    '9999-01-01-00.00.00.000000' AS comp_end_dttm,
    '' AS comp_ds
FROM
	session.tmp_stage_probe t1,
        bwm.cust_lookup cust,
        bwm.centr_lookup centr
WHERE
  (cust.value = t1.probe_host OR cust.value = '@') AND
  (centr.value = t1.probe_host OR centr.value = '@') AND
  NOT EXISTS (
   SELECT 1
   FROM
     session.tmp_cdw_probe t2
   WHERE
     t1.probe = t2.probe and
     t1.probe_host = t2.probe_host
 )
GROUP BY
  t1.probe, t1.probe_host, t1.probe_id,centr.centr_cd, cust.cust_id
;

-----------------------------------------------------------
-- Add CompReln for PROBE to BWM_HOST , IP_HOST, (RUNSON)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm)
SELECT DISTINCT
    0 AS Compreln_id,
    c2.comp_id AS comp_source_id,
    c1.comp_id AS comp_target_id,
    'RUNSON' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2,
    BWM.STAGE_NODE n1,
    BWM.STAGE_HOST h1
WHERE
    c1.CompTyp_Cd  in ('BWM_HOST', 'IP_HOST') AND
    c2.CompTyp_Cd = 'BWM_PROBE' AND
    n1.host_id=h1.host_id and
    c2.Comp_corr_val = h1.host_name AND
    INTEGER(n1.appl_id)=c2.comp_corr_id and
    c1.comp_nm=h1.host_name and
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c2.comp_id = c3.comp_source_id AND
    c1.comp_id = c3.comp_target_id AND
    c3.relntyp_cd='RUNSON'
    );


-----------------------------------------------------------
--Create a temp table with 1 row per Policy already in
--the Staging
-----------------------------------------------------------
DECLARE GLOBAL TEMPORARY TABLE tmp_stage_policy (
  policy_name VARCHAR(254),
  policy_id   INTEGER
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


INSERT INTO session.tmp_stage_policy
SELECT DISTINCT
    name as policy_name,
    INTEGER(UUID1) as policy_id
FROM
    BWM.STAGE_MGMTPOLICY
;

-----------------------------------------------------------
--Create a temp table with 1 row per BWM_TX_NODE already in
--the Staging
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp_stage_txnd(
  txnd_Invok_User   VARCHAR(254),
  j2ee_server VARCHAR(254),
  j2ee_node   VARCHAR(254),
  j2ee_cell   VARCHAR(254),
  j2ee_domain VARCHAR(254),
  j2ee_app_type VARCHAR(254),
  j2ee_app_vers VARCHAR(254),
  probe_name	VARCHAR(254),
  txnd_host_name VARCHAR(254),
  txnd_mgmt_policy VARCHAR(254),
  tx_name	VARCHAR(4000),
  tx_desc  VARCHAR(254),
  tx_id    INTEGER,
  txnd_seq  INTEGER,
  root_seq INTEGER,
  parent_seq VARCHAR(254)
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;

INSERT INTO session.tmp_stage_txnd
SELECT
  u.user_name as txnd_Invok_User,
  j.j2ee_server as j2ee_server,
  j.j2ee_node as j2ee_node,
  j.j2ee_cell as j2ee_cell,
  j.j2ee_domain as j2ee_domain,
  j.j2ee_app_type as j2ee_app_type,
  j.j2ee_app_vers as j2ee_app_vers,
  '' as probe_name,
  h.host_name as txnd_host_name,
  p.policy_name as txnd_mgmt_policy,
  tx.tx_name as tx_name,
  tx.tx_desc as tx_desc,
  INTEGER(tx.tx_id) as tx_id,
  INTEGER(nd.node_sequence) AS txnd_seq,
  INTEGER(nd2.node_sequence) as root_seq,
  rtrim(char(INTEGER(nd3.node_sequence))) as parent_seq
FROM
    BWM.STAGE_NODE nd,
    BWM.STAGE_NODE nd2,
    BWM.STAGE_NODE nd3,
    BWM.STAGE_HOST h,
    session.tmp_stage_j2ee j,
    BWM.app1 a1,
    BWM.STAGE_USER u,
    session.tmp_stage_policy p,
    BWM.STAGE_TRANSACTION tx,
    BWM.STAGE_RELATIONMAP r
where
    a1.appkey1 = 'J2EE' and
    a1.appl_id=INTEGER(nd.appl_id) and
    j.j2ee_id=INTEGER(nd.appl_id) and
    tx.tx_id = nd.tx_id and
    h.host_id = nd.host_id and
    u.user_id = nd.user_id and
    p.policy_id = INTEGER(r.MGMT_POLICY_OM_ID) and
    nd.node_id=r.current_node_id and
    r.root_node_id=nd2.node_id and
    r.parent_node_id=nd3.node_id and
    r.parent_node_id is not null
group by
  u.user_name,
  j.j2ee_server,
  j.j2ee_node,
  j.j2ee_cell,
  j.j2ee_domain,
  j.j2ee_app_type,
  j.j2ee_app_vers,
  h.host_name,
  p.policy_name,
  tx.tx_name,
  tx.tx_desc,
  tx.tx_id,
  nd.node_sequence,
  nd2.node_sequence,
  nd3.node_sequence
;

INSERT INTO session.tmp_stage_txnd
SELECT
  u.user_name as txnd_Invok_User,
  j.j2ee_server as j2ee_server,
  j.j2ee_node as j2ee_node,
  j.j2ee_cell as j2ee_cell,
  j.j2ee_domain as j2ee_domain,
  j.j2ee_app_type as j2ee_app_type,
  j.j2ee_app_vers as j2ee_app_vers,
  '' as probe_name,
  h.host_name as txnd_host_name,
  p.policy_name as txnd_mgmt_policy,
  tx.tx_name as tx_name,
  tx.tx_desc as tx_desc,
  INTEGER(tx.tx_id) as tx_id,
  INTEGER(nd.node_sequence) AS txnd_seq,
  INTEGER(nd2.node_sequence) as root_seq,
  'N/A' as parent_seq
FROM
    BWM.STAGE_NODE nd,
    BWM.STAGE_NODE nd2,
    BWM.STAGE_HOST h,
    session.tmp_stage_j2ee j,
    BWM.app1 a1,
    BWM.STAGE_USER u,
    session.tmp_stage_policy p,
    BWM.STAGE_TRANSACTION tx,
    BWM.STAGE_RELATIONMAP r
where
    a1.appkey1 = 'J2EE' and
    a1.appl_id=INTEGER(nd.appl_id) and
    j.j2ee_id=INTEGER(nd.appl_id) and
    tx.tx_id = nd.tx_id and
    h.host_id = nd.host_id and
    u.user_id = nd.user_id and
    p.policy_id = INTEGER(r.MGMT_POLICY_OM_ID) and
    nd.node_id=r.current_node_id and
    r.root_node_id=nd2.node_id and
    r.parent_node_id is null
group by
  u.user_name,
  j.j2ee_server,
  j.j2ee_node,
  j.j2ee_cell,
  j.j2ee_domain,
  j.j2ee_app_type,
  j.j2ee_app_vers,
  h.host_name,
  p.policy_name,
  tx.tx_name,
  tx.tx_desc,
  tx.tx_id,
  nd.node_sequence,
  nd2.node_sequence
;

INSERT INTO session.tmp_stage_txnd
SELECT
  u.user_name as txnd_Invok_User,
  '' as j2ee_server,
  '' as j2ee_node,
  '' as j2ee_cell,
  '' as j2ee_domain,
  '' as j2ee_app_type,
  '' as j2ee_app_vers,
  a1.appkey1 as probe_name,
  h.host_name as txnd_host_name,
  p.policy_name as txnd_mgmt_policy,
  tx.tx_name as tx_name,
  tx.tx_desc as tx_desc,
  INTEGER(tx.tx_id) as tx_id,
  INTEGER(nd.node_sequence) AS txnd_seq,
  INTEGER(nd2.node_sequence) as root_seq,
  rtrim(char(INTEGER(nd3.node_sequence))) as parent_seq
FROM
    BWM.STAGE_NODE nd,
    BWM.STAGE_NODE nd2,
    BWM.STAGE_NODE nd3,
    BWM.STAGE_HOST h,
    BWM.app1 a1,
    BWM.STAGE_USER u,
    session.tmp_stage_policy p,
    BWM.STAGE_TRANSACTION tx,
    BWM.STAGE_RELATIONMAP r
where
    a1.appkey1 in ('QOS', 'STI','GenWin') and
    a1.appl_id=INTEGER(nd.appl_id) and
    tx.tx_id = nd.tx_id and
    h.host_id = nd.host_id and
    u.user_id = nd.user_id and
    p.policy_id = INTEGER(r.MGMT_POLICY_OM_ID) and
    nd.node_id=r.current_node_id and
    r.root_node_id=nd2.node_id and
    r.parent_node_id=nd3.node_id
group by
  u.user_name,
  h.host_name,
  p.policy_name,
  a1.appkey1,
  tx.tx_name,
  tx.tx_desc,
  tx.tx_id,
  nd.node_sequence,
  nd2.node_sequence,
  nd3.node_sequence
;

INSERT INTO session.tmp_stage_txnd
SELECT
  u.user_name as txnd_Invok_User,
  '' as j2ee_server,
  '' as j2ee_node,
  '' as j2ee_cell,
  '' as j2ee_domain,
  '' as j2ee_app_type,
  '' as j2ee_app_vers,
  a1.appkey1 as probe_name,
  h.host_name as txnd_host_name,
  p.policy_name as txnd_mgmt_policy,
  tx.tx_name as tx_name,
  tx.tx_desc as tx_desc,
  INTEGER(tx.tx_id) as tx_id,
  INTEGER(nd.node_sequence) AS txnd_seq,
  INTEGER(nd2.node_sequence) as root_seq,
  'N/A' as parent_seq
FROM
    BWM.STAGE_NODE nd,
    BWM.STAGE_NODE nd2,
    BWM.STAGE_HOST h,
    BWM.app1 a1,
    BWM.STAGE_USER u,
    session.tmp_stage_policy p,
    BWM.STAGE_TRANSACTION tx,
    BWM.STAGE_RELATIONMAP r
where
    a1.appkey1 in ('QOS', 'STI','GenWin') and
    a1.appl_id=INTEGER(nd.appl_id) and
    tx.tx_id = nd.tx_id and
    h.host_id = nd.host_id and
    u.user_id = nd.user_id and
    p.policy_id = INTEGER(r.MGMT_POLICY_OM_ID) and
    nd.node_id=r.current_node_id and
    r.root_node_id=nd2.node_id and
    r.parent_node_id is null
group by
  u.user_name,
  h.host_name,
  p.policy_name,
  a1.appkey1,
  tx.tx_name,
  tx.tx_desc,
  tx.tx_id,
  nd.node_sequence,
  nd2.node_sequence
;

--select * from session.tmp_stage_txnd;
-----------------------------------------------------------
-- Create a temp table with 1 row per BWM_TX_NODE already in
-- the CDW
-----------------------------------------------------------


DECLARE GLOBAL TEMPORARY TABLE tmp_cdw_txnd (
--  txnd_Invok_User   VARCHAR(254),
--  j2ee_server VARCHAR(254),
--  j2ee_node   VARCHAR(254),
--  j2ee_cell   VARCHAR(254),
--  j2ee_domain VARCHAR(254),
--  j2ee_app_type VARCHAR(254),
--  j2ee_app_vers VARCHAR(254),
--  probe_name	VARCHAR(254),
--  txnd_host_name VARCHAR(254),
--  txnd_mgmt_policy VARCHAR(254),
--  tx_name	VARCHAR(4000),
--  tx_desc  VARCHAR(254),
  txnd_id INTEGER
--  root_txnd_seq INTEGER,
--  parent_txnd_seq VARCHAR(254)
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;

-- Transaction node against a J2EE

INSERT INTO session.tmp_cdw_txnd
SELECT
c1.comp_corr_id
--  ca2.compattr_val as txnd_Invok_User,
--  c2.comp_nm as j2ee_server,
--  j.j2ee_node as j2ee_node,
--  j.j2ee_cell as j2ee_cell,
--  j.j2ee_domain as j2ee_domain,
--  j.j2ee_app_type as j2ee_app_type,
--  j.j2ee_app_vers as j2ee_app_vers,
--  '' as probe_name,
--  c3.comp_nm as txnd_host_name,
--  ca1.compattr_val as txnd_mgmt_policy,
--  c4.comp_nm as tx_name,
--  c4.comp_ds as tx_desc,
--  c1.comp_id as txnd_id,
--  integer(substr(c1.comp_corr_val, locate('@',c1.comp_corr_val) + 1,locate('!',c1.comp_corr_val) - locate ('@',c1.comp_corr_val) - 1)) as root_txnd_seq,
--  substr(c1.comp_corr_val, locate('!',c1.comp_corr_val) + 1,length(c1.comp_corr_val)) as parent_txnd_seq
FROM
  twg.cur_comp c1
--  twg.cur_compattr ca1,
--  twg.cur_compattr ca2,
--  twg.cur_compreln r1,
--  twg.cur_comp c2,
--  twg.cur_compreln r2,
--  twg.cur_comp c3,
--  session.tmp_cdw_j2ee j,
--  bwm.comp_name_long c4,
--  twg.cur_compreln r3
WHERE
  c1.comptyp_cd = 'BWM_TX_NODE' 
--  r1.relntyp_cd='USES' and
--  r1.comp_source_id=c1.comp_id and
--  r1.comp_target_id=c2.comp_id and
--  c2.comptyp_cd='J2EE_SERVER' and
--  j.j2ee_server_id=c2.comp_id and
--  r2.relntyp_cd='RUNSON' and
-- r2.comp_source_id=c1.comp_id and
--  r2.comp_target_id=c3.comp_id and
--  c3.comptyp_cd in ( 'BWM_HOST', 'IP_HOST') and
--  ca1.attrtyp_cd='BWM_MGMT_POLICY' and
--  ca1.comp_id=c1.comp_id and
--  ca2.attrtyp_cd = 'INVOKING_USER' and
--  ca2.comp_id=c1.comp_id and
--  r3.comp_source_id=c1.comp_id and
--  r3.comp_target_id=c4.comp_id and
--  r3.relntyp_cd='INSTOF'and
--  c4.comptyp_cd='BWM_TRANSACTION'
;

-- Transaction Node against a Probe
--INSERT INTO session.tmp_cdw_txnd
--SELECT
--  ca2.compattr_val as txnd_Invok_User,
--  '' as j2ee_server,
--  '' as j2ee_node,
--  '' as j2ee_cell,
--  '' as j2ee_domain,
--  '' as j2ee_app_type,
--  ''as j2ee_app_vers,
--  p.probe as probe_name,
--  p.probe_host as txnd_host_name,
--  ca1.compattr_val as txnd_mgmt_policy,
--  c4.comp_nm as tx_name,
--  c4.comp_ds as tx_desc,
--  c1.comp_id as txnd_id,
-- integer(substr(c1.comp_corr_val, locate('@',c1.comp_corr_val) + 1,locate('!',c1.comp_corr_val) - locate ('@',c1.comp_corr_val) - 1)) as root_txnd_seq,
--  substr(c1.comp_corr_val, locate('!',c1.comp_corr_val) + 1,length(c1.comp_corr_val)) as parent_txnd_seq
--FROM
--  twg.cur_comp c1,
--  twg.cur_compattr ca1,
--  twg.cur_compattr ca2,
--  session.tmp_cdw_probe p,
--  twg.cur_compreln r1,
--  twg.cur_comp c2,
--  bwm.comp_name_long c4,
--  twg.cur_compreln r3
--WHERE
--  c1.comptyp_cd = 'BWM_TX_NODE' and
--  r1.relntyp_cd='INVOKE' and
--  r1.comp_source_id=c2.comp_id and
--  r1.comp_target_id=c1.comp_id and
--  c2.comptyp_cd='BWM_PROBE' and
--  p.probe_id=c2.comp_id and
--  ca1.attrtyp_cd='BWM_MGMT_POLICY' and
-- ca1.comp_id=c1.comp_id and
--  ca2.attrtyp_cd='INVOKING_USER' and
--  ca2.comp_id=c1.comp_id and
--  r3.comp_source_id=c1.comp_id and
--  r3.comp_target_id=c4.comp_id and
--  r3.relntyp_cd='INSTOF'and
--  c4.comptyp_cd='BWM_TRANSACTION'
--;

-----------------------------------------------------------
--Insert all new bwm TX NODE components into the twg.comp
-----------------------------------------------------------

INSERT INTO twg.comp (comp_id, comptyp_cd, centr_cd, cust_id, comp_nm, comp_corr_id, comp_corr_val, comp_strt_dttm, comp_end_dttm, comp_ds)
SELECT
    0 AS Comp_ID,
    'BWM_TX_NODE' AS Comptyp_cd,
    centr.centr_cd AS centr_cd,
    cust.cust_id AS cust_id,
    CASE
        WHEN length(t1.tx_name) > 245 then substr(t1.tx_name, 1, 240) concat '_' concat char(t1.txnd_seq)
        ELSE t1.tx_name concat '_' concat char(t1.txnd_seq) end AS comp_nm,
    t1.txnd_seq as comp_corr_id,
    t1.txnd_host_name concat '@' concat rtrim(char(t1.root_seq)) concat '!' concat t1.parent_seq AS Comp_Corr_Val,
    CURRENT TIMESTAMP - CURRENT TIMEZONE AS comp_strt_dttm,
    '9999-01-01-00.00.00.000000' AS comp_end_dttm,
    'Transaction Node' AS comp_ds
FROM
  	session.tmp_stage_txnd t1,
        bwm.cust_lookup cust,
        bwm.centr_lookup centr
WHERE
  (cust.value = t1.txnd_host_name OR cust.value = '@') AND
  (centr.value = t1.txnd_host_name OR centr.value = '@') AND
  NOT EXISTS (
   SELECT 1
   FROM
     session.tmp_cdw_txnd t2
   WHERE
     t1.TXND_SEQ = t2.txnd_id
 --    t1.txnd_Invok_User = t2.txnd_Invok_User and
 --    t1.j2ee_server = t2.j2ee_server and
 --    t1.j2ee_node = t2.j2ee_node and
 --    t1.j2ee_cell = t2.j2ee_cell and
 --    t1.j2ee_domain = t2.j2ee_domain and
 --    t1.j2ee_app_type = t2.j2ee_app_type and
 --    t1.j2ee_app_vers = t2.j2ee_app_vers and
 --    t1.probe_name = t2.probe_name and
 --    t1.txnd_host_name = t2.txnd_host_name and
 --    t1.txnd_mgmt_policy = t2.txnd_mgmt_policy and
 --    t1.tx_name = t2.tx_name and
 --    t1.tx_desc = t2.tx_desc and
 --    t1.root_seq = t2.root_txnd_seq and
 --    t1.parent_seq = t2.parent_txnd_seq
 )
;

-----------------------------------------------------------
--Create a temp table with 1 row per BWM_TRANSACTION
--already in the CDW
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp_cdw_tx (
  tx_name VARCHAR(4000),
  tx_desc VARCHAR(254)
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


INSERT INTO session.tmp_cdw_tx
SELECT
    c1.comp_nm AS tx_name,
    c1.comp_ds AS tx_desc
FROM
    bwm.comp_name_long c1
WHERE
    c1.comptyp_cd = 'BWM_TRANSACTION'
;

-----------------------------------------------------------
-- IY53303 - r.someshwar & jmg(L3)
-- Insert all new bwm_transaction components
-- into the temp table that are less than 254 characters.
-----------------------------------------------------------
INSERT INTO session.tmp_cdw_tx
SELECT
    c1.comp_nm AS tx_name,
    c1.comp_ds AS tx_desc
FROM
    twg.cur_comp c1
WHERE
    c1.comptyp_cd = 'BWM_TRANSACTION'
;
-----------------------------------------------------------
-- Insert all new bwm_transaction components
-- into the twg.comp
-- IY53303 - r.someshwar & jmg(L3) - check length of 254 instead of 244
-----------------------------------------------------------

INSERT INTO twg.comp (comp_id, comptyp_cd, centr_cd, cust_id, comp_nm, comp_corr_id, comp_corr_val, comp_strt_dttm, comp_end_dttm, comp_ds)
SELECT
    0 AS Comp_ID,
    'BWM_TRANSACTION' AS Comptyp_cd,
    centr.centr_cd AS centr_cd,
    cust.cust_id AS cust_id,
    CASE
     WHEN LENGTH(t1.tx_name) > 254
     then
     SUBSTR(t1.tx_name, 1, 244) concat '_' concat CHAR(t1.tx_id)
     ELSE
     t1.tx_name
     END AS comp_nm,
     t1.Tx_id  AS Comp_Corr_ID,
     '' as Comp_Corr_Val,
     CURRENT TIMESTAMP - CURRENT TIMEZONE AS comp_strt_dttm,
     '9999-01-01-00.00.00.000000' AS comp_end_dttm,
     t1.tx_desc AS comp_ds
FROM
     session.tmp_stage_txnd t1,
     bwm.cust_lookup cust,
     bwm.centr_lookup centr
WHERE
  (cust.value = t1.txnd_host_name OR cust.value = '@') AND
  (centr.value = t1.txnd_host_name OR centr.value = '@') AND
  NOT EXISTS (
   SELECT 1
   FROM
     session.tmp_cdw_tx t2
   WHERE
     t1.tx_name = t2.tx_name and
     t1.tx_desc = t2.tx_desc

 )
group by
t1.tx_id, t1.tx_name, t1.tx_id, t1.tx_desc, cust.cust_id, centr.centr_cd
;

-----------------------------------------------------------
--Insert all the transactions in the bwm.Comp_name_long as well
-----------------------------------------------------------


INSERT INTO BWM.comp_name_long ( comp_id, comp_nm, comp_ds, comptyp_cd)
select
c1.comp_id as comp_id,
t1.tx_name as comp_nm,
t1.tx_desc as comp_ds,
'BWM_TRANSACTION' as comptyp_cd
from
session.tmp_stage_txnd t1,
twg.cur_comp c1
where
t1.tx_id=c1.comp_corr_id and
length(t1.tx_name) > 254 and
c1.comptyp_cd='BWM_TRANSACTION' and
not exists (
 select 1
 from
  bwm.comp_name_long c2
 where
  c2.comp_id=c1.comp_id
  )
group by
c1.comp_id,
t1.tx_name,
t1.tx_desc
;

-----------------------------------------------------------
-- Add CompReln for BWM_TX_NODE to BWM_HOST , IP_HOST (RUNSON)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm )
SELECT DISTINCT
    0 AS Compreln_id,
    c2.comp_id AS comp_source_id,
    c1.comp_id AS comp_target_id,
    'RUNSON' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2,
    BWM.STAGE_NODE n1,
    BWM.STAGE_HOST h1,
    session.tmp_stage_txnd t1
WHERE
    c1.CompTyp_Cd in ('BWM_HOST','IP_HOST') AND
    c2.CompTyp_Cd = 'BWM_TX_NODE' AND
    n1.host_id=h1.host_id AND
    c2.Comp_corr_val = h1.host_name concat '@' concat rtrim(char(t1.root_seq)) concat '!' concat t1.parent_seq AND
    INTEGER(n1.node_sequence) = c2.comp_corr_id AND
    t1.txnd_seq = INTEGER(n1.node_sequence) AND
    c1.comp_nm=h1.host_name AND
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c2.comp_id = c3.comp_source_id
    AND c1.comp_id = c3.comp_target_id
    AND c3.relntyp_cd='RUNSON')
;

-----------------------------------------------------------
-- Add CompReln for BWM_PROBE to BWM_TX_NODE (INVOKE)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm )
SELECT DISTINCT
    0 AS Compreln_id,
    c2.comp_id AS comp_source_id,
    c1.comp_id AS comp_target_id,
    'INVOKE' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2,
    BWM.STAGE_NODE n1,
    BWM.stage_application a1,
    BWM.stage_host h1
WHERE
    c1.CompTyp_Cd = 'BWM_TX_NODE' AND
    c2.CompTyp_Cd = 'BWM_PROBE' AND
    c2.comp_corr_id = INTEGER(n1.appl_id) and
    a1.appl_id=n1.appl_id and
    a1.appl_name=c2.comp_nm and
    n1.host_id=h1.host_id and
    h1.host_name=c2.comp_corr_val and
    c1.comp_corr_id = INTEGER(n1.node_sequence) and
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c2.comp_id = c3.comp_source_id AND
    c1.comp_id = c3.comp_target_id AND
    c3.relntyp_cd='INVOKE'
    );

-----------------------------------------------------------
-- Add CompReln for BWM_TX_NODE to J2EE_SERVER (USES)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm )
SELECT DISTINCT
    0 AS Compreln_id,
    c1.comp_id AS comp_source_id,
    c2.comp_id AS comp_target_id,
    'USES' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2,
    BWM.STAGE_NODE n1,
    BWM.app1 a1
WHERE
    c1.CompTyp_Cd = 'BWM_TX_NODE' AND
    c2.CompTyp_Cd = 'J2EE_SERVER' AND
    c2.comp_corr_id = a1.appl_id and
    a1.appkey1='J2EE' and
    INTEGER(n1.appl_id)=a1.appl_id and
    c1.comp_corr_id = INTEGER(n1.node_sequence) and
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c1.comp_id = c3.comp_source_id AND
    c2.comp_id = c3.comp_target_id AND
    c3.relntyp_cd='USES'
    )
    ;
-----------------------------------------------------------
-- Add CompReln for PROBE to Transaction (PCHILD)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm )
SELECT DISTINCT
    0 AS Compreln_id,
    c2.comp_id AS comp_source_id,
    c1.comp_id AS comp_target_id,
    'PCHILD' AS relntyp_cd,
    c1.comp_strt_dttm AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2,
    BWM.STAGE_NODE n1,
    BWM.STAGE_TRANSACTION t1
WHERE
    c1.CompTyp_Cd = 'BWM_TRANSACTION' AND
    c2.CompTyp_Cd = 'BWM_PROBE' AND
    c2.comp_corr_id = INTEGER(n1.appl_id) and
    c1.comp_corr_id = INTEGER(t1.tx_id) and
    t1.tx_id = n1.tx_id and
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c2.comp_id = c3.comp_source_id
    AND c1.comp_id = c3.comp_target_id
    AND c3.relntyp_cd='PCHILD'
    );

-----------------------------------------------------------
-- Add CompReln for BWM_TX_NODE to BWM_TRANSACTION (INSTOF)
-----------------------------------------------------------

INSERT INTO TWG.CompReln (Compreln_id, comp_source_id, comp_target_id, relntyp_cd, compreln_strt_dttm, compreln_end_dttm )
SELECT DISTINCT
    0 AS Compreln_id,
    c2.comp_id AS comp_source_id,
    c1.comp_id AS comp_target_id,
    'INSTOF' AS relntyp_cd,
    current timestamp - current timezone AS compreln_strt_dttm,
   '9999-01-01-00.00.00.000000' AS compreln_end_dttm
FROM
    twg.cur_comp c1,
    twg.cur_comp c2,
    BWM.STAGE_NODE n1,
    BWM.STAGE_TRANSACTION t1
WHERE
    c1.CompTyp_Cd = 'BWM_TRANSACTION' AND
    c2.CompTyp_Cd = 'BWM_TX_NODE' AND
    c1.comp_corr_id = INTEGER(t1.tx_id) and
    c2.comp_corr_id = INTEGER(n1.node_sequence) and
    t1.tx_id = n1.tx_id and
    NOT EXISTS(
    SELECT 1 FROM twg.cur_compreln c3
    WHERE
    c2.comp_id = c3.comp_source_id
    AND c1.comp_id = c3.comp_target_id
    AND c3.relntyp_cd='INSTOF'
    )
group by
c2.comp_id,
c1.comp_id;

-----------------------------------------------------------
-- LAST_IP_ADDRESS Attribute
-- We need to insert an attribute if it is a new one
-- or if the attribute value has changed
-- the trigger in the CDW database will automatically close
-- the old attribute value.
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp2_cdw_host (
  comp_id   INTEGER,
  comp_nm VARCHAR(254)
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


INSERT INTO session.tmp2_cdw_host
SELECT
    comp_id as comp_id,
    comp_nm AS comp_nm
FROM
    twg.cur_comp
WHERE
    comptyp_cd in ('IP_HOST','BWM_HOST')
;


DECLARE GLOBAL TEMPORARY TABLE tmp1_attr_host_ip(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_attr_host_ip
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd in ('IP_INTERFACE', 'BWM_HOST') and
    ca.attrtyp_cd='LAST_IP_ADDRESS' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_attr_host_ip (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_attr_host_ip
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_host c1 left outer join session.tmp1_attr_host_ip ca1
 on ( c1.comp_id = ca1.comp_id)
;

-----------------------------------------------------------------------------------
-- We can have multiple records in the host table for the same host name, each with a
-- different ip address.  But, since the host_id column is created by the DB
-- on a trigger, the record with the greatest host_id would be the one
-- with the latest ip_address.
-- Create a temporary table of stage_host called stage2_host
-- than only contain the last ip_address for the same host_name.
------------------------------------------------------------------------------------
declare global temporary table stage2_host (
  HOST_ID           INTEGER NOT NULL,
  HOST_NAME         VARCHAR(64),
  HOST_IP_ADDRESS   VARCHAR(15)
)
with replace on commit preserve rows not logged
;

insert into session.stage2_host
select
   INTEGER(host_id),
   host_name,
   host_ip_address
from
   bwm.stage_host
where
   INTEGER(host_id) in (
select
   max(INTEGER(host_id))
from
   bwm.stage_host
group by
   host_name
)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'LAST_IP_ADDRESS' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 h.host_ip_address as CompAttr_Val
from
 session.stage2_host h,
 session.tmp2_cdw_host c1,
 session.tmp2_attr_host_ip ca1
where
  c1.comp_nm=h.host_name and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, h.host_ip_address
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'LAST_IP_ADDRESS' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 h.host_ip_address as CompAttr_Val
from
 session.stage2_host h,
 session.tmp2_cdw_host c1,
 session.tmp2_attr_host_ip ca1
where
  c1.comp_nm=h.host_name and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is not null and
  ca1.last_value != h.host_ip_address
group by
  c1.comp_id,  h.host_ip_address
;

--select * from twg.compattr;


---------------------------------------------------------
--- Add J2EE_NODE as a Component Attribute of the TX NODE
---------------------------------------------------------


DECLARE GLOBAL TEMPORARY TABLE tmp2_cdw_txnd (
  txnd_name VARCHAR(254),
  comp_id   INTEGER,
  txnd_id   INTEGER,
  txnd_rt_id VARCHAR(254),
  txnd_pt_id VARCHAR(254)
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


INSERT INTO session.tmp2_cdw_txnd
SELECT
    comp_nm AS txnd_name,
    comp_id AS comp_id,
    comp_corr_id as txnd_id,
    substr(comp_corr_val, locate('@',comp_corr_val) + 1,locate('!',comp_corr_val) - locate ('@',comp_corr_val) - 1) as txnd_rt_id,
    substr(comp_corr_val, locate('!',comp_corr_val) + 1,length(comp_corr_val)) AS  txnd_pt_id
FROM
    twg.cur_comp
WHERE
    comptyp_cd = 'BWM_TX_NODE'
;


DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_j2eend(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_j2eend
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd='J2EE_NODE' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_j2eend (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_j2eend
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_j2eend ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'J2EE_NODE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 c3.comp_nm as CompAttr_Val
from
 twg.cur_compreln r1,
 twg.cur_compreln r2,
 twg.cur_comp c1,
 twg.cur_comp c2,
 twg.cur_comp c3,
 session.tmp2_txnd_j2eend ca1
where
  r1.relntyp_cd='USES' and
  r1.comp_source_id=c1.comp_id and
  c1.comptyp_cd='BWM_TX_NODE' and
  c2.comp_id=r1.comp_target_id and
  c2.comptyp_cd='J2EE_SERVER' and
  r1.comp_target_id=r2.comp_target_id and
  r2.comp_source_id=c3.comp_id and
  r2.relntyp_cd='PCHILD' and
  c3.comptyp_cd='J2EE_NODE' and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id , c3.comp_nm
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'J2EE_NODE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 c3.comp_nm as CompAttr_Val
from
 twg.cur_compreln r1,
 twg.cur_compreln r2,
 twg.cur_comp c1,
 twg.cur_comp c2,
 twg.cur_comp c3,
 session.tmp2_txnd_j2eend ca1
where
  r1.relntyp_cd='USES' and
  r1.comp_source_id=c1.comp_id and
  c1.comptyp_cd='BWM_TX_NODE' and
  c2.comp_id=r1.comp_target_id and
  c2.comptyp_cd='J2EE_SERVER' and
  r1.comp_target_id=r2.comp_target_id and
  r2.comp_source_id=c3.comp_id and
  r2.relntyp_cd='PCHILD' and
  c3.comptyp_cd='J2EE_NODE' and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is not null and
  ca1.last_value != c3.comp_nm
group by
  c1.comp_id,  c3.comp_nm
;

--select * from twg.compattr;

---------------------------------------------------------
--- Add J2EE Server as a Component Attribute of the TX NODE
---------------------------------------------------------


DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_j2eesv(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_j2eesv
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd='J2EE_SERVER' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_j2eesv (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_j2eesv
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_j2eesv ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'J2EE_SERVER' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 c2.comp_nm as CompAttr_Val
from
 twg.cur_compreln r1,
 twg.cur_comp c1,
 twg.cur_comp c2,
 session.tmp2_txnd_j2eesv ca1
where
  r1.relntyp_cd='USES' and
  r1.comp_source_id=c1.comp_id and
  c1.comptyp_cd='BWM_TX_NODE' and
  c2.comp_id=r1.comp_target_id and
  c2.comptyp_cd='J2EE_SERVER' and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, c2.comp_nm
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'J2EE_SERVER' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 c2.comp_nm as CompAttr_Val
from
 twg.cur_compreln r1,
 twg.cur_comp c1,
 twg.cur_comp c2,
 session.tmp2_txnd_j2eend ca1
where
  r1.relntyp_cd='USES' and
  r1.comp_source_id=c1.comp_id and
  c1.comptyp_cd='BWM_TX_NODE' and
  c2.comp_id=r1.comp_target_id and
  c2.comptyp_cd='J2EE_SERVER' and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is not null and
  ca1.last_value != c2.comp_nm
group by
  c1.comp_id,  c2.comp_nm
;

--select * from twg.compattr;

---------------------------------------------------------
--- Add J2EE Cell as a Component Attribute of the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_j2eecl(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_j2eecl
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd='J2EE_CELL' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_j2eecl (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_j2eecl
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_j2eecl ca1
 on ( c1.comp_id = ca1.comp_id)
;


 insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'J2EE_CELL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 c4.comp_nm as CompAttr_Val
from
 twg.cur_compreln r1,
 twg.cur_compreln r2,
 twg.cur_compreln r3,
 twg.cur_comp c1,
 twg.cur_comp c2,
 twg.cur_comp c3,
 twg.cur_comp c4,
 session.tmp2_txnd_j2eend ca1
where
  r1.relntyp_cd='USES' and
  r1.comp_source_id=c1.comp_id and
  c1.comptyp_cd='BWM_TX_NODE' and
  c2.comp_id=r1.comp_target_id and
  c2.comptyp_cd='J2EE_SERVER' and
  r1.comp_target_id=r2.comp_target_id and
  r2.comp_source_id=c3.comp_id and
  r2.relntyp_cd='PCHILD' and
  c3.comptyp_cd='J2EE_NODE' and
  r2.comp_source_id=r3.comp_target_id and
  r3.comp_source_id=c4.comp_id and
  c4.comptyp_cd='J2EE_CELL' and
  ca1.comp_id=c4.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, c4.comp_nm
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'J2EE_CELL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 c4.comp_nm as CompAttr_Val
from
 twg.cur_compreln r1,
 twg.cur_compreln r2,
 twg.cur_compreln r3,
 twg.cur_comp c1,
 twg.cur_comp c2,
 twg.cur_comp c3,
 twg.cur_comp c4,
 session.tmp2_txnd_j2eend ca1
where
  r1.relntyp_cd='USES' and
  r1.comp_source_id=c1.comp_id and
  c1.comptyp_cd='BWM_TX_NODE' and
  c2.comp_id=r1.comp_target_id and
  c2.comptyp_cd='J2EE_SERVER' and
  r1.comp_target_id=r2.comp_target_id and
  r2.comp_source_id=c3.comp_id and
  r2.relntyp_cd='PCHILD' and
  c3.comptyp_cd='J2EE_NODE' and
  r2.comp_source_id=r3.comp_target_id and
  r3.comp_source_id=c4.comp_id and
  c4.comptyp_cd='J2EE_CELL' and
  ca1.comp_id=c4.comp_id and
  ca1.last_value is not null and
  ca1.last_value != c4.comp_nm
group by
  c1.comp_id,  c4.comp_nm
;

--select * from twg.compattr;

---------------------------------------------------------
--- Add J2EE Domain as a Component Attribute of the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_j2eedm(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_j2eedm
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd='J2EE_DOMAIN' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_j2eedm (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_j2eedm
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_j2eedm ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'J2EE_DOMAIN' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 c3.comp_nm as CompAttr_Val
from
 twg.cur_compreln r1,
 twg.cur_compreln r2,
 twg.cur_comp c1,
 twg.cur_comp c2,
 twg.cur_comp c3,
 session.tmp2_txnd_j2eend ca1
where
  r1.relntyp_cd='USES' and
  r1.comp_source_id=c1.comp_id and
  c1.comptyp_cd='BWM_TX_NODE' and
  c2.comp_id=r1.comp_target_id and
  c2.comptyp_cd='J2EE_SERVER' and
  r1.comp_target_id=r2.comp_target_id and
  r2.comp_source_id=c3.comp_id and
  r2.relntyp_cd='PCHILD' and
  c3.comptyp_cd='J2EE_DOMAIN' and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, c3.comp_nm
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'J2EE_DOMAIN' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 c3.comp_nm as CompAttr_Val
from
 twg.cur_compreln r1,
 twg.cur_compreln r2,
 twg.cur_comp c1,
 twg.cur_comp c2,
 twg.cur_comp c3,
 session.tmp2_txnd_j2eend ca1
where
  r1.relntyp_cd='USES' and
  r1.comp_source_id=c1.comp_id and
  c1.comptyp_cd='BWM_TX_NODE' and
  c2.comp_id=r1.comp_target_id and
  c2.comptyp_cd='J2EE_SERVER' and
  r1.comp_target_id=r2.comp_target_id and
  r2.comp_source_id=c3.comp_id and
  r2.relntyp_cd='PCHILD' and
  c3.comptyp_cd='J2EE_DOMAIN' and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is not null and
  ca1.last_value != c3.comp_nm
group by
  c1.comp_id,  c3.comp_nm
;

--select * from twg.compattr;

-----------------------------------------------------------
--Create a temp table with 1 row per USER already in
--the Staging
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp_stage_user (
  user_name VARCHAR(254),
  user_id   INTEGER
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


INSERT INTO session.tmp_stage_user
SELECT DISTINCT
    user_name as user_name,
    INTEGER(user_id) as user_id
FROM
    BWM.STAGE_USER
;

---------------------------------------------------------
--- Add Invoking User as a Component Attribute
-- of the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_user(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_user
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'INVOKING_USER' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_user (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_user
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_user ca1
 on ( c1.comp_id = ca1.comp_id)
;


 insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'INVOKING_USER' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 u.user_name as CompAttr_Val
from
 BWM.stage_user u,
 BWM.Stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_user ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.user_id=u.user_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, u.user_name
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'INVOKING_USER' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 u.user_name as CompAttr_Val
from
 BWM.stage_user u,
 BWM.Stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_user ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.user_id=u.user_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is not null and
  ca1.last_value != u.user_name
group by
  c1.comp_id,  u.user_name
;

--select * from twg.compattr;


---------------------------------------------------------
-- Add IP_ADDRESS as a Component Attribute of
-- the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_ip(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_ip
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd= 'LAST_IP_ADDRESS' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_ip (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_ip
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_ip ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'LAST_IP_ADDRESS' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 h.host_ip_address as CompAttr_Val
from
 session.stage2_host h,
 bwm.stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_ip ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  INTEGER(n.host_id) = h.host_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, h.host_ip_address
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'LAST_IP_ADDRESS' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 h.host_ip_address as CompAttr_Val
from
 session.stage2_host h,
 bwm.stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_ip ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  INTEGER(n.host_id) = h.host_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is not null and
  ca1.last_value != h.host_ip_address
group by
  c1.comp_id,  h.host_ip_address
;

--select * from twg.compattr;



-----------------------------------------------------------
--Parse Protocol out of transaction name
-----------------------------------------------------------


DECLARE GLOBAL TEMPORARY TABLE protocol (
    tx_name VARCHAR(4000),
    tx_id INTEGER,
    tx_protocol VARCHAR(254)
) WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;



INSERT INTO session.protocol
SELECT
    CASE
     WHEN LOCATE('://', tx_name) > 0
     then
     SUBSTR(tx_name, LOCATE('://',tx_name)+3) CONCAT '!!'
     END AS tx_name,
     INTEGER(tx_ID),
     CASE
     WHEN LOCATE('http://',tx_name) > 0
     then
     	'http'
     else
     	case
     	when locate('https://',tx_name) >0
     	then 'https'
     	else 'UNKNOWN'
     	end
     end AS tx_protocol
FROM
 bwm.stage_transaction
WHERE
    Locate('://', tx_name) > 0
 ;

-----------------------------------------------------------
--Parse Website out of transaction name
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE website (
    tx_name VARCHAR(4000),
    tx_id INTEGER,
   tx_website VARCHAR(254)
) WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;



INSERT INTO session.website
SELECT
    CASE
    -- found a / in the string
     WHEN LOCATE('/', tx_name) > 0
     then
     SUBSTR(tx_name, LOCATE('/',tx_name)+1)
     ELSE
      tx_name
     END AS tx_name,
     tx_ID,
     CASE
     -- found a / in the string
     WHEN LOCATE('/',tx_name)  > 0
     then
      SUBSTR(tx_name,1,LOCATE('/',tx_name)-1 )
     else
      tx_name
     END AS tx_website
FROM
 session.protocol
where
  tx_name<>'!!'
;


-----------------------------------------------------------
--Parse Website Path out of transaction name
-----------------------------------------------------------


DECLARE GLOBAL TEMPORARY TABLE website_path (
    tx_name VARCHAR(4000),
    tx_id INTEGER,
    tx_website_path VARCHAR(4000)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;



INSERT INTO session.website_path
SELECT
    CASE
     WHEN LOCATE('?', tx_name)  > 0
     then
     SUBSTR(tx_name, LOCATE('?',tx_name)+1)
     ELSE
        '!!'
     END as tx_name,
     tx_ID,
     CASE
     WHEN LOCATE('?',tx_name) > 0
     then SUBSTR(tx_name,1,LOCATE('?',tx_name) - 1)
     else SUBSTR(tx_name,1,LOCATE('!',tx_name) - 1)
     END AS tx_website_path
FROM
     session.website
WHERE
     tx_name <>'!!'
;

-----------------------------------------------------------
--Parse Website Query out of transaction name
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE website_query (
    tx_name VARCHAR(4000),
    tx_id INTEGER,
    tx_website_query VARCHAR(4000)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;



INSERT INTO session.website_query
SELECT
     tx_name AS tx_name,
     tx_ID,
     SUBSTR(tx_name,1,LOCATE('!',tx_name) - 1) AS tx_website_query
FROM
  session.website_path
WHERE
 tx_name <>'!!'
 ;

---------------------------------------------------------
-- Add URL_PROTOCOL as a Component Attribute of
-- the TX NODE
---------------------------------------------------------
DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_prot(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_prot
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'URL_PROTOCOL' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_prot (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_prot
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_prot ca1
 on ( c1.comp_id = ca1.comp_id)
;


 insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'URL_PROTOCOL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 p.tx_protocol as CompAttr_Val
from
 session.protocol p,
 BWM.Stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_prot ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  INTEGER(n.tx_id)=p.tx_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, p.tx_protocol
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'URL_PROTOCOL' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 p.tx_protocol as CompAttr_Val
from
 session.protocol p,
 BWM.Stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_prot ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  INTEGER(n.tx_id)=p.tx_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is not null and
  ca1.last_value != p.tx_protocol
group by
  c1.comp_id,  p.tx_protocol
;

--select * from twg.compattr;

---------------------------------------------------------
-- Add Website as a Component Attribute of
-- the TX NODE
---------------------------------------------------------


DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_website(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_website
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'WEBSITE' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_website (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_website
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_website ca1
 on ( c1.comp_id = ca1.comp_id)
;


 insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'WEBSITE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 w.tx_website as CompAttr_Val
from
 session.website w,
 BWM.Stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_website ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  INTEGER(n.tx_id)=w.tx_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, w.tx_website
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'WEBSITE' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 w.tx_website as CompAttr_Val
from
 session.website w,
 BWM.Stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_website ca1
where
  c1.txnd_id=n.node_sequence and
  INTEGER(n.tx_id)=w.tx_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is not null and
  ca1.last_value != w.tx_website
group by
  c1.comp_id,  w.tx_website
;

--select * from twg.compattr;

--------------------------------------------------------
-- Add Website Path as a Component Attribute of
-- the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_webstpt(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_webstpt
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'WEBSITE_PATH' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_webstpt (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_webstpt
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_webstpt ca1
 on ( c1.comp_id = ca1.comp_id)
;


 insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'WEBSITE_PATH' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 case when length(wp.tx_website_path)>254 then substr(wp.tx_website_path, 1, 254) 
 else substr(wp.tx_website_path, 1, length(wp.tx_website_path)) end as CompAttr_Val
from
 session.website_path wp,
 BWM.Stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_webstpt ca1
where
  c1.txnd_id=n.node_sequence and
  INTEGER(n.tx_id)=wp.tx_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, wp.tx_website_path
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'WEBSITE_PATH' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 case when length(wp.tx_website_path)>254 then substr(wp.tx_website_path, 1, 254) 
 else substr(wp.tx_website_path, 1, length(wp.tx_website_path)) end as CompAttr_Val
from
 session.website_path wp,
 BWM.Stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_webstpt ca1
where
  c1.txnd_id=n.node_sequence and
  INTEGER(n.tx_id)=wp.tx_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is not null and
  ca1.last_value != wp.tx_website_path
group by
  c1.comp_id,  wp.tx_website_path
;

--select * from twg.compattr;

DECLARE GLOBAL TEMPORARY TABLE tmp3_txnd_webstpt(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp3_txnd_webstpt
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'WEBSITE_PATH' and
    ca.comp_id=c.comp_id
    ;


------------------------------------------------------
-- Insert WEBSITE_PATH in BWM.COMP_ATTR_LONG
------------------------------------------------------
INSERT INTO BWM.comp_attr_long (compattr_id,comp_id, compattr_val, attrtyp_cd)
select
ca1.compattr_id as compattr_id,
t1.comp_id as comp_id,
t1.last_value compattr_val,
'WEBSITE_PATH' as attrtyp_cd
from
session.tmp3_txnd_webstpt t1,
twg.cur_compattr ca1,
twg.cur_comp c1
where
t1.comp_id=ca1.comp_id and
ca1.comp_id=c1.comp_id and
length(t1.last_value) > 254 and
c1.comptyp_cd='BWM_TX_NODE' and
ca1.attrtyp_cd='WEBSITE_PATH' and
not exists (
 select 1
 from
  bwm.comp_attr_long c2
 where
  c2.comp_id=t1.comp_id and
  c2.compattr_id=ca1.compattr_id and
  c2.compattr_val=t1.last_value
  )
;

---------------------------------------------------------
-- Add Website Query as a Component Attribute of
-- the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_webstqr(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_webstqr
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'WEBSITE_QUERY' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_webstqr(
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_webstqr
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_webstqr ca1
 on ( c1.comp_id = ca1.comp_id)
;


 insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'WEBSITE_QUERY' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 case when length(wq.tx_website_query)>254 then substr(wq.tx_website_query, 1, 254) 
 else substr(wq.tx_website_query, 1, length(wq.tx_website_query)) end as CompAttr_Val
from
 session.website_query wq,
 BWM.Stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_webstqr ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  INTEGER(n.tx_id)=wq.tx_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, wq.tx_website_query
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'WEBSITE_QUERY' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 case when length(wq.tx_website_query)>254 then substr(wq.tx_website_query, 1, 254) 
 else substr(wq.tx_website_query, 1, length(wq.tx_website_query)) end as CompAttr_Val
from
 session.website_query wq,
 BWM.Stage_node n,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_webstqr ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  INTEGER(n.tx_id)=wq.tx_id and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is not null and
  ca1.last_value != wq.tx_website_query
group by
  c1.comp_id,  wq.tx_website_query
;

--select * from twg.compattr;

DECLARE GLOBAL TEMPORARY TABLE tmp3_txnd_webstqr(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp3_txnd_webstqr
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'WEBSITE_QUERY' and
    ca.comp_id=c.comp_id
    ;

------------------------------------------------------
-- Insert WebSite_query in BWM.COMP_ATTR_LONG
------------------------------------------------------
INSERT INTO BWM.comp_attr_long (compattr_id,comp_id, compattr_val, attrtyp_cd)
select
ca1.compattr_id as compattr_id,
t1.comp_id as comp_id,
t1.last_value compattr_val,
'WEBSITE_QUERY' as attrtyp_cd
from
session.tmp1_txnd_webstqr t1,
twg.cur_compattr ca1,
twg.cur_comp c1
where
t1.comp_id=ca1.comp_id and
ca1.comp_id=c1.comp_id and
length(t1.last_value) > 254 and
c1.comptyp_cd='BWM_TX_NODE' and
ca1.attrtyp_cd='WEBSITE_QUERY' and
not exists (
 select 1
 from
  bwm.comp_attr_long c2
 where
  c2.comp_id=t1.comp_id and
  c2.compattr_id=ca1.compattr_id and
  c2.compattr_val=t1.last_value
  )
;

---------------------------------------------------------
-- Add THRESHOLD1 as a Component Attribute of
-- the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_th1(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_th1
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'BWM_THRESHOLD_1' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_th1(
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_th1
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_th1 ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_1' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th1 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=10 and
  -- we need to take the threshold value that is the closest to the
  -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
(INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
    from
	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=10 
     group by
  	 n1.node_sequence
                       ) and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, t.thresholdvalue , ag.coll_datetime
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_1' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th1 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=10 and
  ca1.comp_id=c1.comp_id and
  -- we need to take the threshold value that is the closest to the
  -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
  (INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
    from
	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=10
     group by
  	 n1.node_sequence
                       ) and
  ca1.last_value is not null and
  ca1.last_value != char(INTEGER(t.thresholdvalue))
group by
  c1.comp_id,  t.thresholdvalue, ag.coll_datetime
;

--select * from twg.compattr;

---------------------------------------------------------
-- Add THRESHOLD2 as a Component Attribute of
-- the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_th2(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_th2
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'BWM_THRESHOLD_2' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_th2(
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_th2
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_th2 ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_2' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th2 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=20 and
  -- we need to take the threshold value that is the closest to the
  -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
  (INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
      from
      	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=20 
     group by
  	 n1.node_sequence
                       ) and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, t.thresholdvalue, ag.coll_datetime
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_2' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th2 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=20 and
  ca1.comp_id=c1.comp_id and
  -- we need to take the threshold value that is the closest to the
  -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
  (INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
    from
	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=20 
     group by
  	 n1.node_sequence
                       ) and
  ca1.last_value is not null and
  ca1.last_value != char(INTEGER(t.thresholdvalue))
group by
  c1.comp_id,  t.thresholdvalue, ag.coll_datetime
;

--select * from twg.compattr;

---------------------------------------------------------
-- Add THRESHOLD3 as a Component Attribute of
-- the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_th3(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_th3
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'BWM_THRESHOLD_3' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_th3(
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_th3
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_th3 ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_3' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th3 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=30 and
 -- we need to take the threshold value that is the closest to the
 -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
  (INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
    from
	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=30 
     group by
  	 n1.node_sequence
                              ) and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, t.thresholdvalue, ag.coll_datetime
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_3' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th3 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=30 and
  ca1.comp_id=c1.comp_id and
  -- we need to take the threshold value that is the closest to the
 -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
  (INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
    from
	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=30 
     group by
  	 n1.node_sequence
                       ) and
  ca1.last_value is not null and
  ca1.last_value != char(INTEGER(t.thresholdvalue))
group by
  c1.comp_id,  t.thresholdvalue, ag.coll_datetime
;

--select * from twg.compattr;

---------------------------------------------------------
-- Add THRESHOLD4 as a Component Attribute of
-- the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_th4(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_th4
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'BWM_THRESHOLD_4' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_th4(
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_th4
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_th4 ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_4' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th4 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=40 and
  -- we need to take the threshold value that is the closest to the
  -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
  (INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
    from
	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=40 
     group by
  	 n1.node_sequence
                       ) and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, t.thresholdvalue, ag.coll_datetime
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_4' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th4 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=40 and
  ca1.comp_id=c1.comp_id and
  -- we need to take the threshold value that is the closest to the
  -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
  (INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
    from
	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=40 
     group by
  	 n1.node_sequence
                       ) and
  ca1.last_value is not null and
  ca1.last_value != char(INTEGER(t.thresholdvalue))
group by
  c1.comp_id,  t.thresholdvalue, ag.coll_datetime
;

--select * from twg.compattr;

---------------------------------------------------------
-- Add THRESHOLD5 as a Component Attribute of
-- the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_th5(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_th5
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'BWM_THRESHOLD_5' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_th5(
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_th5
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_th5 ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_5' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th5 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=50 and
  -- we need to take the threshold value that is the closest to the
  -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
  (INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
    from
	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=50 
     group by
  	 n1.node_sequence
                       ) and
  ca1.comp_id=c1.comp_id and
  ca1.last_value is null
group by
  c1.comp_id, t.thresholdvalue, ag.coll_datetime
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_5' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th5 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=50 and
  ca1.comp_id=c1.comp_id and
  -- we need to take the threshold value that is the closest to the
  -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
  (INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
    from
	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=50 
     group by
  	 n1.node_sequence
                       ) and
  ca1.last_value is not null and
  ca1.last_value != char(INTEGER(t.thresholdvalue))
group by
  c1.comp_id,  t.thresholdvalue, ag.coll_datetime
;

--select * from twg.compattr;

---------------------------------------------------------
-- Add THRESHOLD6 as a Component Attribute of
-- the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_th6(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_th6
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'BWM_THRESHOLD_6' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_th6(
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_th6
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_th6 ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_6' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th6 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=60 and
  ca1.comp_id=c1.comp_id and
  -- we need to take the threshold value that is the closest to the
  -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
  (INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
    from
	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=60 
     group by
  	 n1.node_sequence
                       ) and
  ca1.last_value is null
group by
  c1.comp_id , t.thresholdvalue, ag.coll_datetime
 ;
 


--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_THRESHOLD_6' as AttrTyp_Cd,
 ag.coll_datetime as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(INTEGER(t.thresholdvalue)) as CompAttr_Val
from
 BWM.Stage_node n,
 BWM.Stage_RelationMap r,
 BWM.Stage_Aggreg_Data ag,
 BWM.Stage_pattern pt,
 BWM.Stage_threshold t,
 BWM.Stage_tr tr,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_th6 ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.relationmap_id=ag.relationmap_id and
  ag.patt_trans_om_id=pt.uuid1 and
  pt.uuid1=t.pattern_id and
  tr.uuid1=t.tr_uuid and
  INTEGER(tr.responselevel)=60 and
  ca1.comp_id=c1.comp_id and
  -- we need to take the threshold value that is the closest to the
  -- average value of the measurement in case we extract
  -- multiple days and the threshold has changed during that days or
  -- in case we have multiple values for the same date and time
  (INTEGER(n.node_sequence), (INTEGER(t.thresholdvalue) - INTEGER(ag.average_value))) in (
    select INTEGER(n1.node_sequence),
      min(INTEGER(t1.thresholdvalue) - INTEGER(ag1.average_value))
    from
	 BWM.Stage_node n1,
         BWM.Stage_RelationMap r1,
         BWM.Stage_Aggreg_Data ag1,
         BWM.Stage_pattern pt1,
         BWM.Stage_threshold t1,
         BWM.Stage_tr tr1
    where
  	 n1.node_id=r1.current_node_id and
  	 r1.relationmap_id=ag1.relationmap_id and
  	 ag1.patt_trans_om_id=pt1.uuid1 and
  	 pt1.uuid1=t1.pattern_id and
  	 tr1.uuid1=t1.tr_uuid and
  	 INTEGER(tr1.responselevel)=60 
     group by
  	 n1.node_sequence
                       ) and
  ca1.last_value is not null and
  ca1.last_value != char(INTEGER(t.thresholdvalue))
group by
  c1.comp_id,  t.thresholdvalue, ag.coll_datetime
;

--select * from twg.compattr;

-----------------------------------------------------------
-- MANANAGEMENT POLICY ATTRIBUTE
-- Create a temp table with 1 row per Policy already in
-- the Staging
-----------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp_stage_policy (
  policy_name VARCHAR(254),
  policy_id   INTEGER
)
WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED
;


INSERT INTO session.tmp_stage_policy
SELECT DISTINCT
    name as policy_name,
    INTEGER(UUID1) as policy_id
FROM
    BWM.STAGE_MGMTPOLICY
;

---------------------------------------------------------
--- Add Management Policy as a Component Attribute
-- of the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_policy(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_policy
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'BWM_MGMT_POLICY' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_policy (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_policy
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_policy ca1
 on ( c1.comp_id = ca1.comp_id)
;


 insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_MGMT_POLICY' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 mp.name as CompAttr_Val
from
 BWM.stage_MGMTPOLICY mp,
 BWM.Stage_node n,
 BWM.STAGE_RELATIONMAP r,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_policy ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  ca1.comp_id=c1.comp_id and
  r.MGMT_POLICY_OM_ID = mp.UUID1  AND
  ca1.last_value is null
group by
  c1.comp_id, mp.name
;

--select * from twg.compattr;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_MGMT_POLICY' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 mp.name as CompAttr_Val
from
 BWM.stage_MGMTPOLICY mp,
 BWM.Stage_node n,
 BWM.STAGE_RELATIONMAP r,
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_policy ca1
where
  c1.txnd_id=INTEGER(n.node_sequence) and
  n.node_id=r.current_node_id and
  r.MGMT_POLICY_OM_ID=mp.UUID1 AND
  ca1.comp_id=c1.comp_id and
  ca1.last_value is not null and
  ca1.last_value != mp.name
group by
  c1.comp_id,  mp.name
;

--select * from twg.compattr;


---------------------------------------------------------
--- Add BWM_RT_CDW_ID as a Component Attribute
-- of the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_root_id(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_root_id
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'BWM_RT_CDW_ID' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_root_id (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_root_id
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_root_id ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_RT_CDW_ID' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(r.comp_target_id) as CompAttr_Val
from
 session.tmp2_cdw_txnd c1,
 session.tmp2_cdw_txnd c2,
 TWG.CUR_COMPRELN r,
 session.tmp2_txnd_root_id ca1
where
 ca1.comp_id=c1.comp_id and
 ca1.last_value is null and
 integer(c1.txnd_rt_id)=c2.txnd_id and
 c2.comp_id=r.comp_source_id and
 r.relntyp_cd='INSTOF'
group by
  c1.comp_id, r.comp_target_id
;

--select * from twg.compattr;


--insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
--select
-- 0 as compattr_id,
-- c1.comp_id as comp_id,
-- 'BWM_RT_CDW_ID' as AttrTyp_Cd,
-- current timestamp - current timezone as CompAttr_Strt_DtTm,
-- '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
-- char(r.comp_target_id)  as CompAttr_Val
--from
--session.tmp2_cdw_txnd c1,
-- session.tmp2_cdw_txnd c2,
-- TWG.CUR_COMPRELN r,
-- session.tmp2_txnd_root_id ca1
--where
--  ca1.comp_id=c1.comp_id and
--  ca1.last_value is not null and
--  integer(c1.txnd_rt_id)=c2.txnd_id and
--  ca1.last_value != char(r.comp_target_id) and
--  c2.comp_id=r.comp_source_id and
--  r.relntyp_cd='INSTOF'
--group by
-- c1.comp_id, r.comp_target_id
--;

--select * from twg.compattr;

---------------------------------------------------------
--- Add BWM_PT_CDW_ID as a Component Attribute
-- of the TX NODE
---------------------------------------------------------

DECLARE GLOBAL TEMPORARY TABLE tmp1_txnd_parent_id(
     comp_id INTEGER,
     last_value VARCHAR(254)
)WITH REPLACE ON COMMIT PRESERVE ROWS NOT LOGGED;


Insert into session.tmp1_txnd_parent_id
select
    ca.comp_id as comp_id,
    ca.compattr_val as last_value
from
    twg.cur_compattr ca,
    twg.cur_comp c
where
    c.comptyp_cd = 'BWM_TX_NODE' and
    ca.attrtyp_cd = 'BWM_PT_CDW_ID' and
    ca.comp_id=c.comp_id
    ;


declare global temporary table tmp2_txnd_parent_id (
  Comp_id        integer,
  Last_Value     varchar(254)
)
with replace on commit preserve rows not logged
;


insert into session.tmp2_txnd_parent_id
select
 c1.comp_id as Comp_id,
 ca1.last_value as Last_Value
from
 session.tmp2_cdw_txnd c1 left outer join session.tmp1_txnd_parent_id ca1
 on ( c1.comp_id = ca1.comp_id)
;


insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_PT_CDW_ID' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 char(r.comp_target_id) as CompAttr_Val
from
 session.tmp2_cdw_txnd c1,
 session.tmp2_cdw_txnd c2,
 TWG.CUR_COMPRELN r,
 session.tmp2_txnd_parent_id ca1
where
 ca1.comp_id=c1.comp_id and
 ca1.last_value is null  and
 c1.txnd_pt_id <> 'N/A' and
 c1.txnd_pt_id <> '' and
 c2.txnd_id=integer(c1.txnd_pt_id) and
 c2.comp_id=r.comp_source_id and
 r.relntyp_cd='INSTOF'
group by
  c1.comp_id, r.comp_target_id
;

insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
select
 0 as compattr_id,
 c1.comp_id as comp_id,
 'BWM_PT_CDW_ID' as AttrTyp_Cd,
 current timestamp - current timezone as CompAttr_Strt_DtTm,
 '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
 'N/A' as CompAttr_Val
from
 session.tmp2_cdw_txnd c1,
 session.tmp2_txnd_parent_id ca1
where
 ca1.comp_id=c1.comp_id and
 ca1.last_value is null  and
 c1.txnd_pt_id ='N/A'
group by
  c1.comp_id
;

--select * from twg.compattr;


--insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
--select
-- 0 as compattr_id,
-- c1.comp_id as comp_id,
-- 'BWM_PT_CDW_ID' as AttrTyp_Cd,
-- current timestamp - current timezone as CompAttr_Strt_DtTm,
-- '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
-- char(r.comp_target_id)  as CompAttr_Val
--from
-- session.tmp2_cdw_txnd c1,
-- session.tmp2_cdw_txnd c2,
-- TWG.CUR_COMPRELN r,
-- session.tmp2_txnd_root_id ca1
--where
--  ca1.comp_id=c1.comp_id and
--  ca1.last_value is not null and
--  integer(c1.txnd_pt_id)=c2.txnd_id and
--  c1.txnd_pt_id <> 'N/A' and
--  ca1.last_value != char(r.comp_target_id) and
--  c2.comp_id=r.comp_source_id and
-- r.relntyp_cd='INSTOF'
--group by
--  c1.comp_id, r.comp_target_id
--;

--insert into twg.compattr (compattr_id, comp_id, AttrTyp_Cd, CompAttr_Strt_DtTm, CompAttr_End_DtTm, CompAttr_Val)
--select
-- 0 as compattr_id,
-- c1.comp_id as comp_id,
-- 'BWM_PT_CDW_ID' as AttrTyp_Cd,
-- current timestamp - current timezone as CompAttr_Strt_DtTm,
-- '9999-01-01-00.00.00.000000' as CompAttr_End_DtTm,
-- 'N/A'  as CompAttr_Val
--from
-- session.tmp2_cdw_txnd c1,
-- session.tmp2_txnd_root_id ca1
--where
--  ca1.comp_id=c1.comp_id and
--  ca1.last_value is not null and
--  c1.txnd_pt_id = 'N/A' and
--  ca1.last_value != 'N/A'
--group by
--  c1.comp_id
--;
--select * from twg.compattr;




---------------------------------------------------
-- Create the temporary msmt table for all the metrics
---------------------------------------------------

declare global temporary table TEMP_MSMT(
  Comp_ID         INTEGER NOT NULL,
  MsmtTyp_ID      INTEGER NOT NULL,
  TmSum_Cd        CHAR NOT NULL,
  Msmt_Strt_Dt    DATE NOT NULL,
  Msmt_Strt_Tm    TIME NOT NULL,
  Msmt_Min_Val    FLOAT,
  Msmt_Max_Val    FLOAT,
  Msmt_Avg_Val    FLOAT,
  Msmt_Tot_Val    FLOAT,
  Msmt_Smpl_Cnt   INTEGER,
  Msmt_Err_Cnt    INTEGER
)
with replace on commit preserve rows not logged
;
-----------------------------------------------------------
--  INSERT Number Threshold Exceeded
-----------------------------------------------------------

insert into session.TEMP_MSMT(
         COMP_ID,
         MSMTTYP_ID,
         TMSUM_CD,
         MSMT_STRT_DT,
         MSMT_STRT_TM,
         MSMT_TOT_VAL,
         MSMT_SMPL_CNT,
         MSMT_ERR_CNT
)
SELECT DISTINCT
   C1.COMP_ID AS COMP_ID,
   M.MSMTTYP_ID AS MSMTTYP_ID,
   S.TMSUM_CD AS TMSUM_CD,
   DATE(AG.COLL_DATETIME) AS MSMT_STRT_DT,
   TIME(AG.COLL_DATETIME) AS MSMT_STRT_TM,
   sum(float(AG.THRESH_VIOL_CNT)) AS MSMT_TOT_VAL,
   avg(float(AG.COUNT)) AS MSMT_SMPL_CNT,
   avg(float(AG.BAD_STATUS_CNT)) AS MSMT_ERR_CNT
FROM
    BWM.STAGE_AGGREG_DATA ag,
    BWM.STAGE_RELATIONMAP rm,
    BWM.STAGE_NODE        nd,
    TWG.MSMTTYP            m,
    TWG.TmSum              s,
    TWG.MsmtRul           mr,
    TWG.cur_comp              c1
WHERE
    M.MSRC_CD = 'BWM'
    AND S.TMSUM_NM = 'Hourly'
    AND M.MSMTTYP_ID = MR.MSMTTYP_ID
    AND M.MSMTTYP_NM = 'Number Threshold Exceeded'
    AND MR.COMPTYP_CD = C1.COMPTYP_CD
    AND C1.COMPTYP_CD = 'BWM_TX_NODE'
    AND c1.comp_corr_id=INTEGER(nd.node_sequence)
    AND ND.NODE_ID = RM.CURRENT_NODE_ID
    AND RM.RELATIONMAP_ID = AG.RELATIONMAP_ID
    AND AG.PARTIAL = '0'
    GROUP BY
   C1.COMP_ID, M.MSMTTYP_ID,
   S.TMSUM_CD, DATE(AG.COLL_DATETIME),
   TIME(AG.COLL_DATETIME)
;

-----------------------------------------------------------
--  INSERT Number of Executions
-----------------------------------------------------------

insert into session.TEMP_MSMT(
         COMP_ID,
         MSMTTYP_ID,
         TMSUM_CD,
         MSMT_STRT_DT,
         MSMT_STRT_TM,
         MSMT_TOT_VAL,
         MSMT_SMPL_CNT,
         MSMT_ERR_CNT
)
SELECT DISTINCT
   C1.COMP_ID AS COMP_ID,
   M.MSMTTYP_ID AS MSMTTYP_ID,
   S.TMSUM_CD AS TMSUM_CD,
   DATE(AG.COLL_DATETIME) AS MSMT_STRT_DT,
   TIME(AG.COLL_DATETIME) AS MSMT_STRT_TM,
   avg(float(AG.COUNT)) AS MSMT_TOT_VAL,
   avg(float(AG.COUNT)) AS MSMT_SMPL_CNT,
   avg(float(AG.BAD_STATUS_CNT)) AS MSMT_ERR_CNT
FROM
    BWM.STAGE_AGGREG_DATA ag,
    BWM.STAGE_RELATIONMAP rm,
    BWM.STAGE_NODE        nd,
    TWG.MSMTTYP            m,
    TWG.TmSum              s,
    TWG.MsmtRul           mr,
    TWG.cur_COMP              c1
WHERE
    M.MSRC_CD = 'BWM'
    AND S.TMSUM_NM = 'Hourly'
    AND M.MSMTTYP_ID = MR.MSMTTYP_ID
    AND M.MSMTTYP_NM = 'Number of Executions'
    AND MR.COMPTYP_CD = C1.COMPTYP_CD
    AND C1.COMPTYP_CD = 'BWM_TX_NODE'
    AND c1.comp_corr_id=INTEGER(nd.node_sequence)
    AND ND.NODE_ID = RM.CURRENT_NODE_ID
    AND RM.RELATIONMAP_ID = AG.RELATIONMAP_ID
    AND AG.PARTIAL = '0'
    GROUP BY
   C1.COMP_ID, M.MSMTTYP_ID,
   S.TMSUM_CD, DATE(AG.COLL_DATETIME),
   TIME(AG.COLL_DATETIME)
;


-----------------------------------------------------------
--  INSERT RESPONSE TIMES
-----------------------------------------------------------

declare global temporary table tmp_sum_ag (
  TOTAL_MIN_VAL      FLOAT,
  TOTAL_MAX_VAL      FLOAT,
  TOTAL_AVG_VAL      FLOAT,
  SUM_COUNT 	 INTEGER,
  SUM_BAD_CNT INTEGER,
  NODE_ID	 CHAR(24) FOR BIT DATA NOT NULL,
  ROOT_ID	 CHAR(24) FOR BIT DATA NOT NULL,
  COLLECT_DTTM	 TIMESTAMP
)
with replace on commit preserve rows not logged
;

insert into session.tmp_sum_ag
 select
  sum(AG.MINIMUM_VALUE*AG.COUNT) AS TOTAL_MIN_VAL,
  SUM(AG.MAXIMUM_VALUE*AG.COUNT) AS TOTAL_MAX_VAL,
  SUM(AG.AVERAGE_VALUE*AG.COUNT) AS TOTAL_AVG_VAL,
  INTEGER(SUM(AG.COUNT)) AS SUM_COUNT,
  INTEGER(SUM(AG.BAD_STATUS_CNT)) AS SUM_BAD_CNT,
  RM.CURRENT_NODE_ID AS NODE_ID,
  RM.ROOT_NODE_ID as ROOT_ID,
  AG.COLL_DATETIME AS COLLECT_DTTM
 from
  bwm.stage_aggreg_data ag,
  bwm.stage_relationmap rm
 where
  RM.RELATIONMAP_ID = AG.RELATIONMAP_ID AND
  AG.PARTIAL = '0' AND
  AG.COUNT - AG.ABORT_STATUS_CNT -  AG.BAD_STATUS_CNT <> 0
 group by
  rm.current_node_id,
  ag.coll_datetime,
  rm.root_node_id
;

insert into session.TEMP_MSMT(
        COMP_ID,
        MSMTTYP_ID,
        TMSUM_CD,
        MSMT_STRT_DT,
        MSMT_STRT_TM,
        MSMT_MIN_VAL,
        MSMT_MAX_VAL,
        MSMT_AVG_VAL,
        MSMT_SMPL_CNT,
        MSMT_ERR_CNT
)
SELECT DISTINCT
   C1.COMP_ID AS COMP_ID,
   M.MSMTTYP_ID AS MSMTTYP_ID,
   S.TMSUM_CD AS TMSUM_CD,
   DATE(AG.COLLECT_DTTM) AS MSMT_STRT_DT,
   TIME(AG.COLLECT_DTTM) AS MSMT_STRT_TM,
   MIN(float(AG.TOTAL_MIN_VAL/AG.SUM_COUNT)) as MSMT_MIN_VAL,
   MAX(float(AG.TOTAL_MAX_VAL/AG.SUM_COUNT)) as MSMT_MAX_VAL,
   AVG(float(AG.TOTAL_AVG_VAL/AG.SUM_COUNT)) as MSMT_AVG_VAL,
   SUM(AG.SUM_COUNT) AS MSMT_SMPL_CNT,
   SUM(AG.SUM_BAD_CNT) AS MSMT_ERR_CNT
FROM
    BWM.STAGE_NODE        nd,
    BWM.STAGE_NODE 	  nd2,
    BWM.STAGE_TRANSACTION tx,
    TWG.MSMTTYP            m,
    TWG.TmSum              s,
    TWG.MsmtRul           mr,
    TWG.cur_COMP              c1,
    SESSION.tmp_sum_ag    AG
WHERE
    M.MSRC_CD = 'MODEL1'
    AND S.TMSUM_NM = 'Hourly'
    AND M.MSMTTYP_ID = MR.MSMTTYP_ID
    AND M.MSMTTYP_NM = 'Response Time'
    AND MR.COMPTYP_CD = C1.COMPTYP_CD
    AND C1.COMPTYP_CD = 'BWM_TX_NODE'
    AND c1.comp_corr_id=INTEGER(nd.node_sequence)
    AND integer(substr(comp_corr_val, locate('@',comp_corr_val) + 1,locate('!',comp_corr_val) - locate ('@',comp_corr_val) - 1))=INTEGER(nd2.node_sequence)
    AND nd2.node_id=ag.root_id
    AND nd.node_id = ag.node_id
    AND tx.tx_id=nd.tx_id
    AND tx.tx_desc not in ('URL','Edge pattern','Service Time', 'Page Render Time', 'Round Trip Time')
    AND ND.NODE_ID = ag.NODE_ID
    GROUP BY
   C1.COMP_ID, M.MSMTTYP_ID,
   S.TMSUM_CD, AG.COLLECT_DTTM
 ;

-----------------------------------------------------------
--  INSERT ROUND TRIP TIME
-----------------------------------------------------------

insert into session.TEMP_MSMT(
        COMP_ID,
        MSMTTYP_ID,
        TMSUM_CD,
        MSMT_STRT_DT,
        MSMT_STRT_TM,
        MSMT_MIN_VAL,
        MSMT_MAX_VAL,
        MSMT_AVG_VAL,
        MSMT_SMPL_CNT,
        MSMT_ERR_CNT
)
SELECT DISTINCT
   C1.COMP_ID AS COMP_ID,
   M.MSMTTYP_ID AS MSMTTYP_ID,
   S.TMSUM_CD AS TMSUM_CD,
   DATE(AG.COLLECT_DTTM) AS MSMT_STRT_DT,
   TIME(AG.COLLECT_DTTM) AS MSMT_STRT_TM,
   MIN(float(AG.TOTAL_MIN_VAL/AG.SUM_COUNT) / 1000) as MSMT_MIN_VAL,
   MAX(float(AG.TOTAL_MAX_VAL/AG.SUM_COUNT) / 1000) as MSMT_MAX_VAL,
   AVG(float(AG.TOTAL_AVG_VAL/AG.SUM_COUNT) / 1000) as MSMT_AVG_VAL,
   SUM(AG.SUM_COUNT) AS MSMT_SMPL_CNT,
   SUM(AG.SUM_BAD_CNT) AS MSMT_ERR_CNT
FROM
    BWM.STAGE_NODE        nd,
    BWM.STAGE_NODE 	  nd2,
    BWM.STAGE_TRANSACTION tx,
    TWG.MSMTTYP            m,
    TWG.TmSum              s,
    TWG.MsmtRul           mr,
    TWG.cur_COMP              c1,
    SESSION.tmp_sum_ag    AG
WHERE
    M.MSRC_CD = 'BWM'
    AND S.TMSUM_NM = 'Hourly'
    AND M.MSMTTYP_ID = MR.MSMTTYP_ID
    AND M.MSMTTYP_NM = 'Round Trip Time'
    AND MR.COMPTYP_CD = C1.COMPTYP_CD
    AND C1.COMPTYP_CD = 'BWM_TX_NODE'
    AND c1.comp_corr_id=INTEGER(nd.node_sequence)
    AND tx.tx_id=nd.tx_id
    AND tx.tx_desc in ('Edge pattern', 'URL','Round Trip Time')
    AND ND.NODE_ID = ag.NODE_ID
    AND integer(substr(comp_corr_val, locate('@',comp_corr_val) + 1,locate('!',comp_corr_val) - locate ('@',comp_corr_val) - 1))=INTEGER(nd2.node_sequence)
    AND nd2.node_id=ag.root_id
GROUP BY
   C1.COMP_ID, M.MSMTTYP_ID,
   S.TMSUM_CD, AG.COLLECT_DTTM
 ;

-----------------------------------------------------------
--  INSERT BACKEND SERVICE TIME
-----------------------------------------------------------

insert into session.TEMP_MSMT(
        COMP_ID,
        MSMTTYP_ID,
        TMSUM_CD,
        MSMT_STRT_DT,
        MSMT_STRT_TM,
        MSMT_MIN_VAL,
        MSMT_MAX_VAL,
        MSMT_AVG_VAL,
        MSMT_SMPL_CNT,
        MSMT_ERR_CNT
)
SELECT DISTINCT
   C1.COMP_ID AS COMP_ID,
   M.MSMTTYP_ID AS MSMTTYP_ID,
   S.TMSUM_CD AS TMSUM_CD,
   DATE(AG.COLLECT_DTTM) AS MSMT_STRT_DT,
   TIME(AG.COLLECT_DTTM) AS MSMT_STRT_TM,
   MIN(float(AG.TOTAL_MIN_VAL/AG.SUM_COUNT) / 1000) as MSMT_MIN_VAL,
   MAX(float(AG.TOTAL_MAX_VAL/AG.SUM_COUNT) / 1000) as MSMT_MAX_VAL,
   AVG(float(AG.TOTAL_AVG_VAL/AG.SUM_COUNT) / 1000) as MSMT_AVG_VAL,
   SUM(AG.SUM_COUNT) AS MSMT_SMPL_CNT,
   SUM(AG.SUM_BAD_CNT) AS MSMT_ERR_CNT
FROM
    BWM.STAGE_NODE        nd,
    BWM.STAGE_NODE 	  nd2,
    BWM.STAGE_TRANSACTION tx,
    TWG.MSMTTYP            m,
    TWG.TmSum              s,
    TWG.MsmtRul           mr,
    TWG.cur_COMP              c1,
    SESSION.tmp_sum_ag    AG
WHERE
    M.MSRC_CD = 'BWM'
    AND S.TMSUM_NM = 'Hourly'
    AND M.MSMTTYP_ID = MR.MSMTTYP_ID
    AND M.MSMTTYP_NM = 'Service Time'
    AND MR.COMPTYP_CD = C1.COMPTYP_CD
    AND C1.COMPTYP_CD = 'BWM_TX_NODE'
    AND c1.comp_corr_id=INTEGER(nd.node_sequence)
    AND tx.tx_id=nd.tx_id
    AND tx.tx_desc = 'Backend Service Time'
    AND ND.NODE_ID = ag.NODE_ID
    AND integer(substr(comp_corr_val, locate('@',comp_corr_val) + 1,locate('!',comp_corr_val) - locate ('@',comp_corr_val) - 1))=INTEGER(nd2.node_sequence)
    AND nd2.node_id=ag.root_id
GROUP BY
   C1.COMP_ID, M.MSMTTYP_ID,
   S.TMSUM_CD, AG.COLLECT_DTTM
 ;

-----------------------------------------------------------
--  INSERT PAGE RENDER TIME
-----------------------------------------------------------

insert into session.TEMP_MSMT(
        COMP_ID,
        MSMTTYP_ID,
        TMSUM_CD,
        MSMT_STRT_DT,
        MSMT_STRT_TM,
        MSMT_MIN_VAL,
        MSMT_MAX_VAL,
        MSMT_AVG_VAL,
        MSMT_SMPL_CNT,
        MSMT_ERR_CNT
)
SELECT DISTINCT
   C1.COMP_ID AS COMP_ID,
   M.MSMTTYP_ID AS MSMTTYP_ID,
   S.TMSUM_CD AS TMSUM_CD,
   DATE(AG.COLLECT_DTTM) AS MSMT_STRT_DT,
   TIME(AG.COLLECT_DTTM) AS MSMT_STRT_TM,
   MIN(float(AG.TOTAL_MIN_VAL/AG.SUM_COUNT) / 1000) as MSMT_MIN_VAL,
   MAX(float(AG.TOTAL_MAX_VAL/AG.SUM_COUNT) / 1000) as MSMT_MAX_VAL,
   AVG(float(AG.TOTAL_AVG_VAL/AG.SUM_COUNT) / 1000) as MSMT_AVG_VAL,
   SUM(AG.SUM_COUNT) AS MSMT_SMPL_CNT,
   SUM(AG.SUM_BAD_CNT) AS MSMT_ERR_CNT
FROM
    BWM.STAGE_NODE        nd,
    BWM.STAGE_NODE 	  nd2,
    BWM.STAGE_TRANSACTION tx,
    TWG.MSMTTYP            m,
    TWG.TmSum              s,
    TWG.MsmtRul           mr,
    TWG.cur_COMP              c1,
    SESSION.tmp_sum_ag    AG
WHERE
    M.MSRC_CD = 'BWM'
    AND S.TMSUM_NM = 'Hourly'
    AND M.MSMTTYP_ID = MR.MSMTTYP_ID
    AND M.MSMTTYP_NM = 'Page Render Time'
    AND MR.COMPTYP_CD = C1.COMPTYP_CD
    AND C1.COMPTYP_CD = 'BWM_TX_NODE'
    AND c1.comp_corr_id=INTEGER(nd.node_sequence)
    AND tx.tx_id=nd.tx_id
    AND tx.tx_desc ='Page Render Time'
    AND ND.NODE_ID = ag.NODE_ID
    AND integer(substr(comp_corr_val, locate('@',comp_corr_val) + 1,locate('!',comp_corr_val) - locate ('@',comp_corr_val) - 1))=INTEGER(nd2.node_sequence)
    AND nd2.node_id=ag.root_id
 GROUP BY
     C1.COMP_ID, M.MSMTTYP_ID,
   S.TMSUM_CD, AG.COLLECT_DTTM
 ;

-----------------------------------------------------------
--  INSERT Sucessful Transactions
-----------------------------------------------------------

insert into session.TEMP_MSMT(
        COMP_ID,
        MSMTTYP_ID,
        TMSUM_CD,
        MSMT_STRT_DT,
        MSMT_STRT_TM,
        MSMT_MIN_VAL,
        MSMT_MAX_VAL,
        MSMT_AVG_VAL,
        MSMT_SMPL_CNT,
        MSMT_ERR_CNT
)
SELECT DISTINCT
   C1.COMP_ID AS COMP_ID,
   M.MSMTTYP_ID AS MSMTTYP_ID,
   S.TMSUM_CD AS TMSUM_CD,
   DATE(AG.COLL_DATETIME) AS MSMT_STRT_DT,
   TIME(AG.COLL_DATETIME) AS MSMT_STRT_TM,
   MIN(float(100.0) * ((float(coalesce(AG.COUNT,0)) - (float(coalesce(AG.BAD_STATUS_CNT,0)))) / float(coalesce(AG.COUNT,0)))) as MSMT_MIN_VAL,
   MAX(float(100.0) * ((float(coalesce(AG.COUNT,0)) - (float(coalesce(AG.BAD_STATUS_CNT,0)))) / float(coalesce(AG.COUNT,0)))) as MSMT_MAX_VAL,
   AVG(float(100.0) * ((float(coalesce(AG.COUNT,0)) - (float(coalesce(AG.BAD_STATUS_CNT,0)))) / float(coalesce(AG.COUNT,0)))) as MSMT_AVG_VAL,
   avg(float(AG.COUNT)) AS MSMT_SMPL_CNT,
   avg(float(AG.BAD_STATUS_CNT)) AS MSMT_ERR_CNT
FROM
    BWM.STAGE_AGGREG_DATA ag,
    BWM.STAGE_RELATIONMAP rm,
    BWM.STAGE_NODE        nd,
    TWG.MSMTTYP            m,
    TWG.TmSum              s,
    TWG.MsmtRul           mr,
    TWG.cur_COMP              c1
WHERE
    M.MSRC_CD = 'BWM'
    AND S.TMSUM_NM = 'Hourly'
    AND M.MSMTTYP_ID = MR.MSMTTYP_ID
    AND M.MSMTTYP_NM = 'Successful Transactions'
    AND MR.COMPTYP_CD = C1.COMPTYP_CD
    AND C1.COMPTYP_CD = 'BWM_TX_NODE'
    AND c1.comp_corr_id=INTEGER(nd.node_sequence)
    AND ND.NODE_ID = RM.CURRENT_NODE_ID
    AND RM.RELATIONMAP_ID = AG.RELATIONMAP_ID
    AND AG.PARTIAL = '0'
    GROUP BY
   C1.COMP_ID, M.MSMTTYP_ID,
   S.TMSUM_CD, DATE(AG.COLL_DATETIME),
   TIME(AG.COLL_DATETIME)
 ;

-----------------------------------------------------------
--  INSERT Unsucessful Transactions
-----------------------------------------------------------

insert into session.TEMP_MSMT(
        COMP_ID,
        MSMTTYP_ID,
        TMSUM_CD,
        MSMT_STRT_DT,
        MSMT_STRT_TM,
        MSMT_MIN_VAL,
        MSMT_MAX_VAL,
        MSMT_AVG_VAL,
        MSMT_SMPL_CNT,
        MSMT_ERR_CNT
)
SELECT DISTINCT
   C1.COMP_ID AS COMP_ID,
   M.MSMTTYP_ID AS MSMTTYP_ID,
   S.TMSUM_CD AS TMSUM_CD,
   DATE(AG.COLL_DATETIME) AS MSMT_STRT_DT,
   TIME(AG.COLL_DATETIME) AS MSMT_STRT_TM,
   MIN(float(100.0) * (float(coalesce(AG.BAD_STATUS_CNT,0)) / float(coalesce(AG.COUNT,0)))) as MSMT_MIN_VAL,
   MAX(float(100.0) * (float(coalesce(AG.BAD_STATUS_CNT,0)) / float(coalesce(AG.COUNT,0)))) as MSMT_MAX_VAL,
   AVG(float(100.0) * (float(coalesce(AG.BAD_STATUS_CNT,0)) / float(coalesce(AG.COUNT,0)))) as MSMT_AVG_VAL,
   avg(float(AG.COUNT)) AS MSMT_SMPL_CNT,
   avg(float(AG.BAD_STATUS_CNT)) AS MSMT_ERR_CNT
FROM
    BWM.STAGE_AGGREG_DATA ag,
    BWM.STAGE_RELATIONMAP rm,
    BWM.STAGE_NODE        nd,
    TWG.MSMTTYP            m,
    TWG.TmSum              s,
    TWG.MsmtRul           mr,
    TWG.cur_COMP              c1
WHERE
    M.MSRC_CD = 'BWM'
    AND S.TMSUM_NM = 'Hourly'
    AND M.MSMTTYP_ID = MR.MSMTTYP_ID
    AND M.MSMTTYP_NM = 'Unsuccessful Transactions'
    AND MR.COMPTYP_CD = C1.COMPTYP_CD
    AND C1.COMPTYP_CD = 'BWM_TX_NODE'
    AND c1.comp_corr_id=INTEGER(nd.node_sequence)
    AND ND.NODE_ID = RM.CURRENT_NODE_ID
    AND RM.RELATIONMAP_ID = AG.RELATIONMAP_ID
    AND AG.PARTIAL = '0'
GROUP BY
   C1.COMP_ID, M.MSMTTYP_ID,
   S.TMSUM_CD, DATE(AG.COLL_DATETIME),
   TIME(AG.COLL_DATETIME)
 ;

INSERT INTO TWG.MSMT
(	MSMT_ID,
        COMP_ID,
        MSMTTYP_ID,
        TMSUM_CD,
        MSMT_STRT_DT,
        MSMT_STRT_TM,
        MSMT_MIN_VAL,
        MSMT_MAX_VAL,
        MSMT_AVG_VAL,
	MSMT_TOT_VAL,
        MSMT_SMPL_CNT,
        MSMT_ERR_CNT
)
SELECT
 0 as MSMT_ID,
 COMP_ID,
 MSMTTYP_ID,
 TMSUM_CD,
 MSMT_STRT_DT,
 MSMT_STRT_TM,
 MSMT_MIN_VAL,
 MSMT_MAX_VAL,
 MSMT_AVG_VAL,
 MSMT_TOT_VAL,
 MSMT_SMPL_CNT,
 MSMT_ERR_CNT
from
 session.TEMP_MSMT
;
